"""
Flet Cupertino Icons

To generate/update these values run:

sh ci/generate_cupertino_icons_python.sh
"""

import random
from enum import Enum
from typing import Dict, List, Optional


class CupertinoIcons(str, Enum):
    @staticmethod
    def random(
        exclude: Optional[List["CupertinoIcons"]] = None,
        weights: Optional[Dict["CupertinoIcons", int]] = None,
    ) -> Optional["CupertinoIcons"]:
        """
        Selects a random icon, with optional exclusions and weights.

        Args:
            exclude: A list of icons members to exclude from the selection.
            weights: A dictionary mapping icon members to their respective weights for weighted random selection.

        Returns:
            A randomly selected icon, or None if all members are excluded.
        """
        choices = list(CupertinoIcons)
        if exclude:
            choices = [member for member in choices if member not in exclude]
            if not choices:
                return None
        if weights:
            weights_list = [weights.get(c, 1) for c in choices]
            return random.choices(choices, weights=weights_list)[0]
        return random.choice(choices)

    LEFT_CHEVRON = "cupertino_left_chevron"
    RIGHT_CHEVRON = "cupertino_right_chevron"
    SHARE = "cupertino_share"
    SHARE_SOLID = "cupertino_share_solid"
    BOOK = "cupertino_book"
    BOOK_SOLID = "cupertino_book_solid"
    BOOKMARK = "cupertino_bookmark"
    BOOKMARK_SOLID = "cupertino_bookmark_solid"
    INFO = "cupertino_info"
    REPLY = "cupertino_reply"
    CONVERSATION_BUBBLE = "cupertino_conversation_bubble"
    PROFILE_CIRCLED = "cupertino_profile_circled"
    PLUS_CIRCLED = "cupertino_plus_circled"
    MINUS_CIRCLED = "cupertino_minus_circled"
    FLAG = "cupertino_flag"
    SEARCH = "cupertino_search"
    CHECK_MARK = "cupertino_check_mark"
    CHECK_MARK_CIRCLED = "cupertino_check_mark_circled"
    CHECK_MARK_CIRCLED_SOLID = "cupertino_check_mark_circled_solid"
    CIRCLE = "cupertino_circle"
    CIRCLE_FILLED = "cupertino_circle_filled"
    BACK = "cupertino_back"
    FORWARD = "cupertino_forward"
    HOME = "cupertino_home"
    SHOPPING_CART = "cupertino_shopping_cart"
    ELLIPSIS = "cupertino_ellipsis"
    PHONE = "cupertino_phone"
    PHONE_SOLID = "cupertino_phone_solid"
    DOWN_ARROW = "cupertino_down_arrow"
    UP_ARROW = "cupertino_up_arrow"
    BATTERY_CHARGING = "cupertino_battery_charging"
    BATTERY_EMPTY = "cupertino_battery_empty"
    BATTERY_FULL = "cupertino_battery_full"
    BATTERY_75_PERCENT = "cupertino_battery_75_percent"
    BATTERY_25_PERCENT = "cupertino_battery_25_percent"
    BLUETOOTH = "cupertino_bluetooth"
    RESTART = "cupertino_restart"
    REPLY_ALL = "cupertino_reply_all"
    REPLY_THICK_SOLID = "cupertino_reply_thick_solid"
    SHARE_UP = "cupertino_share_up"
    SHUFFLE = "cupertino_shuffle"
    SHUFFLE_MEDIUM = "cupertino_shuffle_medium"
    SHUFFLE_THICK = "cupertino_shuffle_thick"
    PHOTO_CAMERA = "cupertino_photo_camera"
    PHOTO_CAMERA_SOLID = "cupertino_photo_camera_solid"
    VIDEO_CAMERA = "cupertino_video_camera"
    VIDEO_CAMERA_SOLID = "cupertino_video_camera_solid"
    SWITCH_CAMERA = "cupertino_switch_camera"
    SWITCH_CAMERA_SOLID = "cupertino_switch_camera_solid"
    COLLECTIONS = "cupertino_collections"
    COLLECTIONS_SOLID = "cupertino_collections_solid"
    FOLDER = "cupertino_folder"
    FOLDER_SOLID = "cupertino_folder_solid"
    FOLDER_OPEN = "cupertino_folder_open"
    DELETE = "cupertino_delete"
    DELETE_SOLID = "cupertino_delete_solid"
    DELETE_SIMPLE = "cupertino_delete_simple"
    PEN = "cupertino_pen"
    PENCIL = "cupertino_pencil"
    CREATE = "cupertino_create"
    CREATE_SOLID = "cupertino_create_solid"
    REFRESH = "cupertino_refresh"
    REFRESH_CIRCLED = "cupertino_refresh_circled"
    REFRESH_CIRCLED_SOLID = "cupertino_refresh_circled_solid"
    REFRESH_THIN = "cupertino_refresh_thin"
    REFRESH_THICK = "cupertino_refresh_thick"
    REFRESH_BOLD = "cupertino_refresh_bold"
    CLEAR_THICK = "cupertino_clear_thick"
    CLEAR_THICK_CIRCLED = "cupertino_clear_thick_circled"
    CLEAR = "cupertino_clear"
    CLEAR_CIRCLED = "cupertino_clear_circled"
    CLEAR_CIRCLED_SOLID = "cupertino_clear_circled_solid"
    ADD = "cupertino_add"
    ADD_CIRCLED = "cupertino_add_circled"
    ADD_CIRCLED_SOLID = "cupertino_add_circled_solid"
    GEAR = "cupertino_gear"
    GEAR_SOLID = "cupertino_gear_solid"
    GEAR_BIG = "cupertino_gear_big"
    SETTINGS = "cupertino_settings"
    SETTINGS_SOLID = "cupertino_settings_solid"
    MUSIC_NOTE = "cupertino_music_note"
    DOUBLE_MUSIC_NOTE = "cupertino_double_music_note"
    PLAY_ARROW = "cupertino_play_arrow"
    PLAY_ARROW_SOLID = "cupertino_play_arrow_solid"
    PAUSE = "cupertino_pause"
    PAUSE_SOLID = "cupertino_pause_solid"
    LOOP = "cupertino_loop"
    LOOP_THICK = "cupertino_loop_thick"
    VOLUME_DOWN = "cupertino_volume_down"
    VOLUME_MUTE = "cupertino_volume_mute"
    VOLUME_OFF = "cupertino_volume_off"
    VOLUME_UP = "cupertino_volume_up"
    FULLSCREEN = "cupertino_fullscreen"
    FULLSCREEN_EXIT = "cupertino_fullscreen_exit"
    MIC_OFF = "cupertino_mic_off"
    MIC = "cupertino_mic"
    MIC_SOLID = "cupertino_mic_solid"
    CLOCK = "cupertino_clock"
    CLOCK_SOLID = "cupertino_clock_solid"
    TIME = "cupertino_time"
    TIME_SOLID = "cupertino_time_solid"
    PADLOCK = "cupertino_padlock"
    PADLOCK_SOLID = "cupertino_padlock_solid"
    EYE = "cupertino_eye"
    EYE_SOLID = "cupertino_eye_solid"
    PERSON = "cupertino_person"
    PERSON_SOLID = "cupertino_person_solid"
    PERSON_ADD = "cupertino_person_add"
    PERSON_ADD_SOLID = "cupertino_person_add_solid"
    GROUP = "cupertino_group"
    GROUP_SOLID = "cupertino_group_solid"
    MAIL = "cupertino_mail"
    MAIL_SOLID = "cupertino_mail_solid"
    LOCATION = "cupertino_location"
    LOCATION_SOLID = "cupertino_location_solid"
    TAG = "cupertino_tag"
    TAG_SOLID = "cupertino_tag_solid"
    TAGS = "cupertino_tags"
    TAGS_SOLID = "cupertino_tags_solid"
    BUS = "cupertino_bus"
    CAR = "cupertino_car"
    CAR_DETAILED = "cupertino_car_detailed"
    TRAIN_STYLE_ONE = "cupertino_train_style_one"
    TRAIN_STYLE_TWO = "cupertino_train_style_two"
    PAW = "cupertino_paw"
    PAW_SOLID = "cupertino_paw_solid"
    GAME_CONTROLLER = "cupertino_game_controller"
    GAME_CONTROLLER_SOLID = "cupertino_game_controller_solid"
    LAB_FLASK = "cupertino_lab_flask"
    LAB_FLASK_SOLID = "cupertino_lab_flask_solid"
    HEART = "cupertino_heart"
    HEART_SOLID = "cupertino_heart_solid"
    BELL = "cupertino_bell"
    BELL_SOLID = "cupertino_bell_solid"
    NEWS = "cupertino_news"
    NEWS_SOLID = "cupertino_news_solid"
    BRIGHTNESS = "cupertino_brightness"
    BRIGHTNESS_SOLID = "cupertino_brightness_solid"
    AIRPLANE = "cupertino_airplane"
    ALARM = "cupertino_alarm"
    ALARM_FILL = "cupertino_alarm_fill"
    ALT = "cupertino_alt"
    ANT = "cupertino_ant"
    ANT_CIRCLE = "cupertino_ant_circle"
    ANT_CIRCLE_FILL = "cupertino_ant_circle_fill"
    ANT_FILL = "cupertino_ant_fill"
    ANTENNA_RADIOWAVES_LEFT_RIGHT = "cupertino_antenna_radiowaves_left_right"
    APP = "cupertino_app"
    APP_BADGE = "cupertino_app_badge"
    APP_BADGE_FILL = "cupertino_app_badge_fill"
    APP_FILL = "cupertino_app_fill"
    ARCHIVEBOX = "cupertino_archivebox"
    ARCHIVEBOX_FILL = "cupertino_archivebox_fill"
    ARROW_2_CIRCLEPATH = "cupertino_arrow_2_circlepath"
    ARROW_2_CIRCLEPATH_CIRCLE = "cupertino_arrow_2_circlepath_circle"
    ARROW_2_CIRCLEPATH_CIRCLE_FILL = "cupertino_arrow_2_circlepath_circle_fill"
    ARROW_2_SQUAREPATH = "cupertino_arrow_2_squarepath"
    ARROW_3_TRIANGLEPATH = "cupertino_arrow_3_trianglepath"
    ARROW_BRANCH = "cupertino_arrow_branch"
    ARROW_CLOCKWISE = "cupertino_arrow_clockwise"
    ARROW_CLOCKWISE_CIRCLE = "cupertino_arrow_clockwise_circle"
    ARROW_CLOCKWISE_CIRCLE_FILL = "cupertino_arrow_clockwise_circle_fill"
    ARROW_COUNTERCLOCKWISE = "cupertino_arrow_counterclockwise"
    ARROW_COUNTERCLOCKWISE_CIRCLE = "cupertino_arrow_counterclockwise_circle"
    ARROW_COUNTERCLOCKWISE_CIRCLE_FILL = "cupertino_arrow_counterclockwise_circle_fill"
    ARROW_DOWN = "cupertino_arrow_down"
    ARROW_DOWN_CIRCLE = "cupertino_arrow_down_circle"
    ARROW_DOWN_CIRCLE_FILL = "cupertino_arrow_down_circle_fill"
    ARROW_DOWN_DOC = "cupertino_arrow_down_doc"
    ARROW_DOWN_DOC_FILL = "cupertino_arrow_down_doc_fill"
    ARROW_DOWN_LEFT = "cupertino_arrow_down_left"
    ARROW_DOWN_LEFT_CIRCLE = "cupertino_arrow_down_left_circle"
    ARROW_DOWN_LEFT_CIRCLE_FILL = "cupertino_arrow_down_left_circle_fill"
    ARROW_DOWN_LEFT_SQUARE = "cupertino_arrow_down_left_square"
    ARROW_DOWN_LEFT_SQUARE_FILL = "cupertino_arrow_down_left_square_fill"
    ARROW_DOWN_RIGHT = "cupertino_arrow_down_right"
    ARROW_DOWN_RIGHT_ARROW_UP_LEFT = "cupertino_arrow_down_right_arrow_up_left"
    ARROW_DOWN_RIGHT_CIRCLE = "cupertino_arrow_down_right_circle"
    ARROW_DOWN_RIGHT_CIRCLE_FILL = "cupertino_arrow_down_right_circle_fill"
    ARROW_DOWN_RIGHT_SQUARE = "cupertino_arrow_down_right_square"
    ARROW_DOWN_RIGHT_SQUARE_FILL = "cupertino_arrow_down_right_square_fill"
    ARROW_DOWN_SQUARE = "cupertino_arrow_down_square"
    ARROW_DOWN_SQUARE_FILL = "cupertino_arrow_down_square_fill"
    ARROW_DOWN_TO_LINE = "cupertino_arrow_down_to_line"
    ARROW_DOWN_TO_LINE_ALT = "cupertino_arrow_down_to_line_alt"
    ARROW_LEFT = "cupertino_arrow_left"
    ARROW_LEFT_CIRCLE = "cupertino_arrow_left_circle"
    ARROW_LEFT_CIRCLE_FILL = "cupertino_arrow_left_circle_fill"
    ARROW_LEFT_RIGHT = "cupertino_arrow_left_right"
    ARROW_LEFT_RIGHT_CIRCLE = "cupertino_arrow_left_right_circle"
    ARROW_LEFT_RIGHT_CIRCLE_FILL = "cupertino_arrow_left_right_circle_fill"
    ARROW_LEFT_RIGHT_SQUARE = "cupertino_arrow_left_right_square"
    ARROW_LEFT_RIGHT_SQUARE_FILL = "cupertino_arrow_left_right_square_fill"
    ARROW_LEFT_SQUARE = "cupertino_arrow_left_square"
    ARROW_LEFT_SQUARE_FILL = "cupertino_arrow_left_square_fill"
    ARROW_LEFT_TO_LINE = "cupertino_arrow_left_to_line"
    ARROW_LEFT_TO_LINE_ALT = "cupertino_arrow_left_to_line_alt"
    ARROW_MERGE = "cupertino_arrow_merge"
    ARROW_RIGHT = "cupertino_arrow_right"
    ARROW_RIGHT_ARROW_LEFT = "cupertino_arrow_right_arrow_left"
    ARROW_RIGHT_ARROW_LEFT_CIRCLE = "cupertino_arrow_right_arrow_left_circle"
    ARROW_RIGHT_ARROW_LEFT_CIRCLE_FILL = "cupertino_arrow_right_arrow_left_circle_fill"
    ARROW_RIGHT_ARROW_LEFT_SQUARE = "cupertino_arrow_right_arrow_left_square"
    ARROW_RIGHT_ARROW_LEFT_SQUARE_FILL = "cupertino_arrow_right_arrow_left_square_fill"
    ARROW_RIGHT_CIRCLE = "cupertino_arrow_right_circle"
    ARROW_RIGHT_CIRCLE_FILL = "cupertino_arrow_right_circle_fill"
    ARROW_RIGHT_SQUARE = "cupertino_arrow_right_square"
    ARROW_RIGHT_SQUARE_FILL = "cupertino_arrow_right_square_fill"
    ARROW_RIGHT_TO_LINE = "cupertino_arrow_right_to_line"
    ARROW_RIGHT_TO_LINE_ALT = "cupertino_arrow_right_to_line_alt"
    ARROW_SWAP = "cupertino_arrow_swap"
    ARROW_TURN_DOWN_LEFT = "cupertino_arrow_turn_down_left"
    ARROW_TURN_DOWN_RIGHT = "cupertino_arrow_turn_down_right"
    ARROW_TURN_LEFT_DOWN = "cupertino_arrow_turn_left_down"
    ARROW_TURN_LEFT_UP = "cupertino_arrow_turn_left_up"
    ARROW_TURN_RIGHT_DOWN = "cupertino_arrow_turn_right_down"
    ARROW_TURN_RIGHT_UP = "cupertino_arrow_turn_right_up"
    ARROW_TURN_UP_LEFT = "cupertino_arrow_turn_up_left"
    ARROW_TURN_UP_RIGHT = "cupertino_arrow_turn_up_right"
    ARROW_UP = "cupertino_arrow_up"
    ARROW_UP_ARROW_DOWN = "cupertino_arrow_up_arrow_down"
    ARROW_UP_ARROW_DOWN_CIRCLE = "cupertino_arrow_up_arrow_down_circle"
    ARROW_UP_ARROW_DOWN_CIRCLE_FILL = "cupertino_arrow_up_arrow_down_circle_fill"
    ARROW_UP_ARROW_DOWN_SQUARE = "cupertino_arrow_up_arrow_down_square"
    ARROW_UP_ARROW_DOWN_SQUARE_FILL = "cupertino_arrow_up_arrow_down_square_fill"
    ARROW_UP_BIN = "cupertino_arrow_up_bin"
    ARROW_UP_BIN_FILL = "cupertino_arrow_up_bin_fill"
    ARROW_UP_CIRCLE = "cupertino_arrow_up_circle"
    ARROW_UP_CIRCLE_FILL = "cupertino_arrow_up_circle_fill"
    ARROW_UP_DOC = "cupertino_arrow_up_doc"
    ARROW_UP_DOC_FILL = "cupertino_arrow_up_doc_fill"
    ARROW_UP_DOWN = "cupertino_arrow_up_down"
    ARROW_UP_DOWN_CIRCLE = "cupertino_arrow_up_down_circle"
    ARROW_UP_DOWN_CIRCLE_FILL = "cupertino_arrow_up_down_circle_fill"
    ARROW_UP_DOWN_SQUARE = "cupertino_arrow_up_down_square"
    ARROW_UP_DOWN_SQUARE_FILL = "cupertino_arrow_up_down_square_fill"
    ARROW_UP_LEFT = "cupertino_arrow_up_left"
    ARROW_UP_LEFT_ARROW_DOWN_RIGHT = "cupertino_arrow_up_left_arrow_down_right"
    ARROW_UP_LEFT_CIRCLE = "cupertino_arrow_up_left_circle"
    ARROW_UP_LEFT_CIRCLE_FILL = "cupertino_arrow_up_left_circle_fill"
    ARROW_UP_LEFT_SQUARE = "cupertino_arrow_up_left_square"
    ARROW_UP_LEFT_SQUARE_FILL = "cupertino_arrow_up_left_square_fill"
    ARROW_UP_RIGHT = "cupertino_arrow_up_right"
    ARROW_UP_RIGHT_CIRCLE = "cupertino_arrow_up_right_circle"
    ARROW_UP_RIGHT_CIRCLE_FILL = "cupertino_arrow_up_right_circle_fill"
    ARROW_UP_RIGHT_DIAMOND = "cupertino_arrow_up_right_diamond"
    ARROW_UP_RIGHT_DIAMOND_FILL = "cupertino_arrow_up_right_diamond_fill"
    ARROW_UP_RIGHT_SQUARE = "cupertino_arrow_up_right_square"
    ARROW_UP_RIGHT_SQUARE_FILL = "cupertino_arrow_up_right_square_fill"
    ARROW_UP_SQUARE = "cupertino_arrow_up_square"
    ARROW_UP_SQUARE_FILL = "cupertino_arrow_up_square_fill"
    ARROW_UP_TO_LINE = "cupertino_arrow_up_to_line"
    ARROW_UP_TO_LINE_ALT = "cupertino_arrow_up_to_line_alt"
    ARROW_UTURN_DOWN = "cupertino_arrow_uturn_down"
    ARROW_UTURN_DOWN_CIRCLE = "cupertino_arrow_uturn_down_circle"
    ARROW_UTURN_DOWN_CIRCLE_FILL = "cupertino_arrow_uturn_down_circle_fill"
    ARROW_UTURN_DOWN_SQUARE = "cupertino_arrow_uturn_down_square"
    ARROW_UTURN_DOWN_SQUARE_FILL = "cupertino_arrow_uturn_down_square_fill"
    ARROW_UTURN_LEFT = "cupertino_arrow_uturn_left"
    ARROW_UTURN_LEFT_CIRCLE = "cupertino_arrow_uturn_left_circle"
    ARROW_UTURN_LEFT_CIRCLE_FILL = "cupertino_arrow_uturn_left_circle_fill"
    ARROW_UTURN_LEFT_SQUARE = "cupertino_arrow_uturn_left_square"
    ARROW_UTURN_LEFT_SQUARE_FILL = "cupertino_arrow_uturn_left_square_fill"
    ARROW_UTURN_RIGHT = "cupertino_arrow_uturn_right"
    ARROW_UTURN_RIGHT_CIRCLE = "cupertino_arrow_uturn_right_circle"
    ARROW_UTURN_RIGHT_CIRCLE_FILL = "cupertino_arrow_uturn_right_circle_fill"
    ARROW_UTURN_RIGHT_SQUARE = "cupertino_arrow_uturn_right_square"
    ARROW_UTURN_RIGHT_SQUARE_FILL = "cupertino_arrow_uturn_right_square_fill"
    ARROW_UTURN_UP = "cupertino_arrow_uturn_up"
    ARROW_UTURN_UP_CIRCLE = "cupertino_arrow_uturn_up_circle"
    ARROW_UTURN_UP_CIRCLE_FILL = "cupertino_arrow_uturn_up_circle_fill"
    ARROW_UTURN_UP_SQUARE = "cupertino_arrow_uturn_up_square"
    ARROW_UTURN_UP_SQUARE_FILL = "cupertino_arrow_uturn_up_square_fill"
    ARROWSHAPE_TURN_UP_LEFT = "cupertino_arrowshape_turn_up_left"
    ARROWSHAPE_TURN_UP_LEFT_2 = "cupertino_arrowshape_turn_up_left_2"
    ARROWSHAPE_TURN_UP_LEFT_2_FILL = "cupertino_arrowshape_turn_up_left_2_fill"
    ARROWSHAPE_TURN_UP_LEFT_CIRCLE = "cupertino_arrowshape_turn_up_left_circle"
    ARROWSHAPE_TURN_UP_LEFT_CIRCLE_FILL = (
        "cupertino_arrowshape_turn_up_left_circle_fill"
    )
    ARROWSHAPE_TURN_UP_LEFT_FILL = "cupertino_arrowshape_turn_up_left_fill"
    ARROWSHAPE_TURN_UP_RIGHT = "cupertino_arrowshape_turn_up_right"
    ARROWSHAPE_TURN_UP_RIGHT_CIRCLE = "cupertino_arrowshape_turn_up_right_circle"
    ARROWSHAPE_TURN_UP_RIGHT_CIRCLE_FILL = (
        "cupertino_arrowshape_turn_up_right_circle_fill"
    )
    ARROWSHAPE_TURN_UP_RIGHT_FILL = "cupertino_arrowshape_turn_up_right_fill"
    ARROWTRIANGLE_DOWN = "cupertino_arrowtriangle_down"
    ARROWTRIANGLE_DOWN_CIRCLE = "cupertino_arrowtriangle_down_circle"
    ARROWTRIANGLE_DOWN_CIRCLE_FILL = "cupertino_arrowtriangle_down_circle_fill"
    ARROWTRIANGLE_DOWN_FILL = "cupertino_arrowtriangle_down_fill"
    ARROWTRIANGLE_DOWN_SQUARE = "cupertino_arrowtriangle_down_square"
    ARROWTRIANGLE_DOWN_SQUARE_FILL = "cupertino_arrowtriangle_down_square_fill"
    ARROWTRIANGLE_LEFT = "cupertino_arrowtriangle_left"
    ARROWTRIANGLE_LEFT_CIRCLE = "cupertino_arrowtriangle_left_circle"
    ARROWTRIANGLE_LEFT_CIRCLE_FILL = "cupertino_arrowtriangle_left_circle_fill"
    ARROWTRIANGLE_LEFT_FILL = "cupertino_arrowtriangle_left_fill"
    ARROWTRIANGLE_LEFT_SQUARE = "cupertino_arrowtriangle_left_square"
    ARROWTRIANGLE_LEFT_SQUARE_FILL = "cupertino_arrowtriangle_left_square_fill"
    ARROWTRIANGLE_RIGHT = "cupertino_arrowtriangle_right"
    ARROWTRIANGLE_RIGHT_CIRCLE = "cupertino_arrowtriangle_right_circle"
    ARROWTRIANGLE_RIGHT_CIRCLE_FILL = "cupertino_arrowtriangle_right_circle_fill"
    ARROWTRIANGLE_RIGHT_FILL = "cupertino_arrowtriangle_right_fill"
    ARROWTRIANGLE_RIGHT_SQUARE = "cupertino_arrowtriangle_right_square"
    ARROWTRIANGLE_RIGHT_SQUARE_FILL = "cupertino_arrowtriangle_right_square_fill"
    ARROWTRIANGLE_UP = "cupertino_arrowtriangle_up"
    ARROWTRIANGLE_UP_CIRCLE = "cupertino_arrowtriangle_up_circle"
    ARROWTRIANGLE_UP_CIRCLE_FILL = "cupertino_arrowtriangle_up_circle_fill"
    ARROWTRIANGLE_UP_FILL = "cupertino_arrowtriangle_up_fill"
    ARROWTRIANGLE_UP_SQUARE = "cupertino_arrowtriangle_up_square"
    ARROWTRIANGLE_UP_SQUARE_FILL = "cupertino_arrowtriangle_up_square_fill"
    ASTERISK_CIRCLE = "cupertino_asterisk_circle"
    ASTERISK_CIRCLE_FILL = "cupertino_asterisk_circle_fill"
    AT = "cupertino_at"
    AT_BADGE_MINUS = "cupertino_at_badge_minus"
    AT_BADGE_PLUS = "cupertino_at_badge_plus"
    AT_CIRCLE = "cupertino_at_circle"
    AT_CIRCLE_FILL = "cupertino_at_circle_fill"
    BACKWARD = "cupertino_backward"
    BACKWARD_END = "cupertino_backward_end"
    BACKWARD_END_ALT = "cupertino_backward_end_alt"
    BACKWARD_END_ALT_FILL = "cupertino_backward_end_alt_fill"
    BACKWARD_END_FILL = "cupertino_backward_end_fill"
    BACKWARD_FILL = "cupertino_backward_fill"
    BADGE_PLUS_RADIOWAVES_RIGHT = "cupertino_badge_plus_radiowaves_right"
    BAG = "cupertino_bag"
    BAG_BADGE_MINUS = "cupertino_bag_badge_minus"
    BAG_BADGE_PLUS = "cupertino_bag_badge_plus"
    BAG_FILL = "cupertino_bag_fill"
    BAG_FILL_BADGE_MINUS = "cupertino_bag_fill_badge_minus"
    BAG_FILL_BADGE_PLUS = "cupertino_bag_fill_badge_plus"
    BANDAGE = "cupertino_bandage"
    BANDAGE_FILL = "cupertino_bandage_fill"
    BARCODE = "cupertino_barcode"
    BARCODE_VIEWFINDER = "cupertino_barcode_viewfinder"
    BARS = "cupertino_bars"
    BATTERY_0 = "cupertino_battery_0"
    BATTERY_100 = "cupertino_battery_100"
    BATTERY_25 = "cupertino_battery_25"
    BED_DOUBLE = "cupertino_bed_double"
    BED_DOUBLE_FILL = "cupertino_bed_double_fill"
    BELL_CIRCLE = "cupertino_bell_circle"
    BELL_CIRCLE_FILL = "cupertino_bell_circle_fill"
    BELL_FILL = "cupertino_bell_fill"
    BELL_SLASH = "cupertino_bell_slash"
    BELL_SLASH_FILL = "cupertino_bell_slash_fill"
    BIN_XMARK = "cupertino_bin_xmark"
    BIN_XMARK_FILL = "cupertino_bin_xmark_fill"
    BITCOIN = "cupertino_bitcoin"
    BITCOIN_CIRCLE = "cupertino_bitcoin_circle"
    BITCOIN_CIRCLE_FILL = "cupertino_bitcoin_circle_fill"
    BOLD = "cupertino_bold"
    BOLD_ITALIC_UNDERLINE = "cupertino_bold_italic_underline"
    BOLD_UNDERLINE = "cupertino_bold_underline"
    BOLT = "cupertino_bolt"
    BOLT_BADGE_A = "cupertino_bolt_badge_a"
    BOLT_BADGE_A_FILL = "cupertino_bolt_badge_a_fill"
    BOLT_CIRCLE = "cupertino_bolt_circle"
    BOLT_CIRCLE_FILL = "cupertino_bolt_circle_fill"
    BOLT_FILL = "cupertino_bolt_fill"
    BOLT_HORIZONTAL = "cupertino_bolt_horizontal"
    BOLT_HORIZONTAL_CIRCLE = "cupertino_bolt_horizontal_circle"
    BOLT_HORIZONTAL_CIRCLE_FILL = "cupertino_bolt_horizontal_circle_fill"
    BOLT_HORIZONTAL_FILL = "cupertino_bolt_horizontal_fill"
    BOLT_SLASH = "cupertino_bolt_slash"
    BOLT_SLASH_FILL = "cupertino_bolt_slash_fill"
    BOOK_CIRCLE = "cupertino_book_circle"
    BOOK_CIRCLE_FILL = "cupertino_book_circle_fill"
    BOOK_FILL = "cupertino_book_fill"
    BOOKMARK_FILL = "cupertino_bookmark_fill"
    BRIEFCASE = "cupertino_briefcase"
    BRIEFCASE_FILL = "cupertino_briefcase_fill"
    BUBBLE_LEFT = "cupertino_bubble_left"
    BUBBLE_LEFT_BUBBLE_RIGHT = "cupertino_bubble_left_bubble_right"
    BUBBLE_LEFT_BUBBLE_RIGHT_FILL = "cupertino_bubble_left_bubble_right_fill"
    BUBBLE_LEFT_FILL = "cupertino_bubble_left_fill"
    BUBBLE_MIDDLE_BOTTOM = "cupertino_bubble_middle_bottom"
    BUBBLE_MIDDLE_BOTTOM_FILL = "cupertino_bubble_middle_bottom_fill"
    BUBBLE_MIDDLE_TOP = "cupertino_bubble_middle_top"
    BUBBLE_MIDDLE_TOP_FILL = "cupertino_bubble_middle_top_fill"
    BUBBLE_RIGHT = "cupertino_bubble_right"
    BUBBLE_RIGHT_FILL = "cupertino_bubble_right_fill"
    BUILDING_2_FILL = "cupertino_building_2_fill"
    BURN = "cupertino_burn"
    BURST = "cupertino_burst"
    BURST_FILL = "cupertino_burst_fill"
    CALENDAR = "cupertino_calendar"
    CALENDAR_BADGE_MINUS = "cupertino_calendar_badge_minus"
    CALENDAR_BADGE_PLUS = "cupertino_calendar_badge_plus"
    CALENDAR_CIRCLE = "cupertino_calendar_circle"
    CALENDAR_CIRCLE_FILL = "cupertino_calendar_circle_fill"
    CALENDAR_TODAY = "cupertino_calendar_today"
    CAMERA = "cupertino_camera"
    CAMERA_CIRCLE = "cupertino_camera_circle"
    CAMERA_CIRCLE_FILL = "cupertino_camera_circle_fill"
    CAMERA_FILL = "cupertino_camera_fill"
    CAMERA_ON_RECTANGLE = "cupertino_camera_on_rectangle"
    CAMERA_ON_RECTANGLE_FILL = "cupertino_camera_on_rectangle_fill"
    CAMERA_ROTATE = "cupertino_camera_rotate"
    CAMERA_ROTATE_FILL = "cupertino_camera_rotate_fill"
    CAMERA_VIEWFINDER = "cupertino_camera_viewfinder"
    CAPSLOCK = "cupertino_capslock"
    CAPSLOCK_FILL = "cupertino_capslock_fill"
    CAPSULE = "cupertino_capsule"
    CAPSULE_FILL = "cupertino_capsule_fill"
    CAPTIONS_BUBBLE = "cupertino_captions_bubble"
    CAPTIONS_BUBBLE_FILL = "cupertino_captions_bubble_fill"
    CAR_FILL = "cupertino_car_fill"
    CART = "cupertino_cart"
    CART_BADGE_MINUS = "cupertino_cart_badge_minus"
    CART_BADGE_PLUS = "cupertino_cart_badge_plus"
    CART_FILL = "cupertino_cart_fill"
    CART_FILL_BADGE_MINUS = "cupertino_cart_fill_badge_minus"
    CART_FILL_BADGE_PLUS = "cupertino_cart_fill_badge_plus"
    CHART_BAR = "cupertino_chart_bar"
    CHART_BAR_ALT_FILL = "cupertino_chart_bar_alt_fill"
    CHART_BAR_CIRCLE = "cupertino_chart_bar_circle"
    CHART_BAR_CIRCLE_FILL = "cupertino_chart_bar_circle_fill"
    CHART_BAR_FILL = "cupertino_chart_bar_fill"
    CHART_BAR_SQUARE = "cupertino_chart_bar_square"
    CHART_BAR_SQUARE_FILL = "cupertino_chart_bar_square_fill"
    CHART_PIE = "cupertino_chart_pie"
    CHART_PIE_FILL = "cupertino_chart_pie_fill"
    CHAT_BUBBLE = "cupertino_chat_bubble"
    CHAT_BUBBLE_2 = "cupertino_chat_bubble_2"
    CHAT_BUBBLE_2_FILL = "cupertino_chat_bubble_2_fill"
    CHAT_BUBBLE_FILL = "cupertino_chat_bubble_fill"
    CHAT_BUBBLE_TEXT = "cupertino_chat_bubble_text"
    CHAT_BUBBLE_TEXT_FILL = "cupertino_chat_bubble_text_fill"
    CHECKMARK = "cupertino_checkmark"
    CHECKMARK_ALT = "cupertino_checkmark_alt"
    CHECKMARK_ALT_CIRCLE = "cupertino_checkmark_alt_circle"
    CHECKMARK_ALT_CIRCLE_FILL = "cupertino_checkmark_alt_circle_fill"
    CHECKMARK_CIRCLE = "cupertino_checkmark_circle"
    CHECKMARK_CIRCLE_FILL = "cupertino_checkmark_circle_fill"
    CHECKMARK_RECTANGLE = "cupertino_checkmark_rectangle"
    CHECKMARK_RECTANGLE_FILL = "cupertino_checkmark_rectangle_fill"
    CHECKMARK_SEAL = "cupertino_checkmark_seal"
    CHECKMARK_SEAL_FILL = "cupertino_checkmark_seal_fill"
    CHECKMARK_SHIELD = "cupertino_checkmark_shield"
    CHECKMARK_SHIELD_FILL = "cupertino_checkmark_shield_fill"
    CHECKMARK_SQUARE = "cupertino_checkmark_square"
    CHECKMARK_SQUARE_FILL = "cupertino_checkmark_square_fill"
    CHEVRON_BACK = "cupertino_chevron_back"
    CHEVRON_COMPACT_DOWN = "cupertino_chevron_compact_down"
    CHEVRON_COMPACT_LEFT = "cupertino_chevron_compact_left"
    CHEVRON_COMPACT_RIGHT = "cupertino_chevron_compact_right"
    CHEVRON_COMPACT_UP = "cupertino_chevron_compact_up"
    CHEVRON_DOWN = "cupertino_chevron_down"
    CHEVRON_DOWN_CIRCLE = "cupertino_chevron_down_circle"
    CHEVRON_DOWN_CIRCLE_FILL = "cupertino_chevron_down_circle_fill"
    CHEVRON_DOWN_SQUARE = "cupertino_chevron_down_square"
    CHEVRON_DOWN_SQUARE_FILL = "cupertino_chevron_down_square_fill"
    CHEVRON_FORWARD = "cupertino_chevron_forward"
    CHEVRON_LEFT = "cupertino_chevron_left"
    CHEVRON_LEFT_2 = "cupertino_chevron_left_2"
    CHEVRON_LEFT_CIRCLE = "cupertino_chevron_left_circle"
    CHEVRON_LEFT_CIRCLE_FILL = "cupertino_chevron_left_circle_fill"
    CHEVRON_LEFT_SLASH_CHEVRON_RIGHT = "cupertino_chevron_left_slash_chevron_right"
    CHEVRON_LEFT_SQUARE = "cupertino_chevron_left_square"
    CHEVRON_LEFT_SQUARE_FILL = "cupertino_chevron_left_square_fill"
    CHEVRON_RIGHT = "cupertino_chevron_right"
    CHEVRON_RIGHT_2 = "cupertino_chevron_right_2"
    CHEVRON_RIGHT_CIRCLE = "cupertino_chevron_right_circle"
    CHEVRON_RIGHT_CIRCLE_FILL = "cupertino_chevron_right_circle_fill"
    CHEVRON_RIGHT_SQUARE = "cupertino_chevron_right_square"
    CHEVRON_RIGHT_SQUARE_FILL = "cupertino_chevron_right_square_fill"
    CHEVRON_UP = "cupertino_chevron_up"
    CHEVRON_UP_CHEVRON_DOWN = "cupertino_chevron_up_chevron_down"
    CHEVRON_UP_CIRCLE = "cupertino_chevron_up_circle"
    CHEVRON_UP_CIRCLE_FILL = "cupertino_chevron_up_circle_fill"
    CHEVRON_UP_SQUARE = "cupertino_chevron_up_square"
    CHEVRON_UP_SQUARE_FILL = "cupertino_chevron_up_square_fill"
    CIRCLE_BOTTOMTHIRD_SPLIT = "cupertino_circle_bottomthird_split"
    CIRCLE_FILL = "cupertino_circle_fill"
    CIRCLE_GRID_3X3 = "cupertino_circle_grid_3x3"
    CIRCLE_GRID_3X3_FILL = "cupertino_circle_grid_3x3_fill"
    CIRCLE_GRID_HEX = "cupertino_circle_grid_hex"
    CIRCLE_GRID_HEX_FILL = "cupertino_circle_grid_hex_fill"
    CIRCLE_LEFTHALF_FILL = "cupertino_circle_lefthalf_fill"
    CIRCLE_RIGHTHALF_FILL = "cupertino_circle_righthalf_fill"
    CLEAR_FILL = "cupertino_clear_fill"
    CLOCK_FILL = "cupertino_clock_fill"
    CLOUD = "cupertino_cloud"
    CLOUD_BOLT = "cupertino_cloud_bolt"
    CLOUD_BOLT_FILL = "cupertino_cloud_bolt_fill"
    CLOUD_BOLT_RAIN = "cupertino_cloud_bolt_rain"
    CLOUD_BOLT_RAIN_FILL = "cupertino_cloud_bolt_rain_fill"
    CLOUD_DOWNLOAD = "cupertino_cloud_download"
    CLOUD_DOWNLOAD_FILL = "cupertino_cloud_download_fill"
    CLOUD_DRIZZLE = "cupertino_cloud_drizzle"
    CLOUD_DRIZZLE_FILL = "cupertino_cloud_drizzle_fill"
    CLOUD_FILL = "cupertino_cloud_fill"
    CLOUD_FOG = "cupertino_cloud_fog"
    CLOUD_FOG_FILL = "cupertino_cloud_fog_fill"
    CLOUD_HAIL = "cupertino_cloud_hail"
    CLOUD_HAIL_FILL = "cupertino_cloud_hail_fill"
    CLOUD_HEAVYRAIN = "cupertino_cloud_heavyrain"
    CLOUD_HEAVYRAIN_FILL = "cupertino_cloud_heavyrain_fill"
    CLOUD_MOON = "cupertino_cloud_moon"
    CLOUD_MOON_BOLT = "cupertino_cloud_moon_bolt"
    CLOUD_MOON_BOLT_FILL = "cupertino_cloud_moon_bolt_fill"
    CLOUD_MOON_FILL = "cupertino_cloud_moon_fill"
    CLOUD_MOON_RAIN = "cupertino_cloud_moon_rain"
    CLOUD_MOON_RAIN_FILL = "cupertino_cloud_moon_rain_fill"
    CLOUD_RAIN = "cupertino_cloud_rain"
    CLOUD_RAIN_FILL = "cupertino_cloud_rain_fill"
    CLOUD_SLEET = "cupertino_cloud_sleet"
    CLOUD_SLEET_FILL = "cupertino_cloud_sleet_fill"
    CLOUD_SNOW = "cupertino_cloud_snow"
    CLOUD_SNOW_FILL = "cupertino_cloud_snow_fill"
    CLOUD_SUN = "cupertino_cloud_sun"
    CLOUD_SUN_BOLT = "cupertino_cloud_sun_bolt"
    CLOUD_SUN_BOLT_FILL = "cupertino_cloud_sun_bolt_fill"
    CLOUD_SUN_FILL = "cupertino_cloud_sun_fill"
    CLOUD_SUN_RAIN = "cupertino_cloud_sun_rain"
    CLOUD_SUN_RAIN_FILL = "cupertino_cloud_sun_rain_fill"
    CLOUD_UPLOAD = "cupertino_cloud_upload"
    CLOUD_UPLOAD_FILL = "cupertino_cloud_upload_fill"
    COLOR_FILTER = "cupertino_color_filter"
    COLOR_FILTER_FILL = "cupertino_color_filter_fill"
    COMMAND = "cupertino_command"
    COMPASS = "cupertino_compass"
    COMPASS_FILL = "cupertino_compass_fill"
    CONTROL = "cupertino_control"
    CREDITCARD = "cupertino_creditcard"
    CREDITCARD_FILL = "cupertino_creditcard_fill"
    CROP = "cupertino_crop"
    CROP_ROTATE = "cupertino_crop_rotate"
    CUBE = "cupertino_cube"
    CUBE_BOX = "cupertino_cube_box"
    CUBE_BOX_FILL = "cupertino_cube_box_fill"
    CUBE_FILL = "cupertino_cube_fill"
    CURSOR_RAYS = "cupertino_cursor_rays"
    DECREASE_INDENT = "cupertino_decrease_indent"
    DECREASE_QUOTELEVEL = "cupertino_decrease_quotelevel"
    DELETE_LEFT = "cupertino_delete_left"
    DELETE_LEFT_FILL = "cupertino_delete_left_fill"
    DELETE_RIGHT = "cupertino_delete_right"
    DELETE_RIGHT_FILL = "cupertino_delete_right_fill"
    DESKTOPCOMPUTER = "cupertino_desktopcomputer"
    DEVICE_DESKTOP = "cupertino_device_desktop"
    DEVICE_LAPTOP = "cupertino_device_laptop"
    DEVICE_PHONE_LANDSCAPE = "cupertino_device_phone_landscape"
    DEVICE_PHONE_PORTRAIT = "cupertino_device_phone_portrait"
    DIAL = "cupertino_dial"
    DIAL_FILL = "cupertino_dial_fill"
    DIVIDE = "cupertino_divide"
    DIVIDE_CIRCLE = "cupertino_divide_circle"
    DIVIDE_CIRCLE_FILL = "cupertino_divide_circle_fill"
    DIVIDE_SQUARE = "cupertino_divide_square"
    DIVIDE_SQUARE_FILL = "cupertino_divide_square_fill"
    DOC = "cupertino_doc"
    DOC_APPEND = "cupertino_doc_append"
    DOC_CHART = "cupertino_doc_chart"
    DOC_CHART_FILL = "cupertino_doc_chart_fill"
    DOC_CHECKMARK = "cupertino_doc_checkmark"
    DOC_CHECKMARK_FILL = "cupertino_doc_checkmark_fill"
    DOC_CIRCLE = "cupertino_doc_circle"
    DOC_CIRCLE_FILL = "cupertino_doc_circle_fill"
    DOC_FILL = "cupertino_doc_fill"
    DOC_ON_CLIPBOARD = "cupertino_doc_on_clipboard"
    DOC_ON_CLIPBOARD_FILL = "cupertino_doc_on_clipboard_fill"
    DOC_ON_DOC = "cupertino_doc_on_doc"
    DOC_ON_DOC_FILL = "cupertino_doc_on_doc_fill"
    DOC_PERSON = "cupertino_doc_person"
    DOC_PERSON_FILL = "cupertino_doc_person_fill"
    DOC_PLAINTEXT = "cupertino_doc_plaintext"
    DOC_RICHTEXT = "cupertino_doc_richtext"
    DOC_TEXT = "cupertino_doc_text"
    DOC_TEXT_FILL = "cupertino_doc_text_fill"
    DOC_TEXT_SEARCH = "cupertino_doc_text_search"
    DOC_TEXT_VIEWFINDER = "cupertino_doc_text_viewfinder"
    DOT_RADIOWAVES_LEFT_RIGHT = "cupertino_dot_radiowaves_left_right"
    DOT_RADIOWAVES_RIGHT = "cupertino_dot_radiowaves_right"
    DOT_SQUARE = "cupertino_dot_square"
    DOT_SQUARE_FILL = "cupertino_dot_square_fill"
    DOWNLOAD_CIRCLE = "cupertino_download_circle"
    DOWNLOAD_CIRCLE_FILL = "cupertino_download_circle_fill"
    DROP = "cupertino_drop"
    DROP_FILL = "cupertino_drop_fill"
    DROP_TRIANGLE = "cupertino_drop_triangle"
    DROP_TRIANGLE_FILL = "cupertino_drop_triangle_fill"
    EAR = "cupertino_ear"
    EJECT = "cupertino_eject"
    EJECT_FILL = "cupertino_eject_fill"
    ELLIPSES_BUBBLE = "cupertino_ellipses_bubble"
    ELLIPSES_BUBBLE_FILL = "cupertino_ellipses_bubble_fill"
    ELLIPSIS_CIRCLE = "cupertino_ellipsis_circle"
    ELLIPSIS_CIRCLE_FILL = "cupertino_ellipsis_circle_fill"
    ELLIPSIS_VERTICAL = "cupertino_ellipsis_vertical"
    ELLIPSIS_VERTICAL_CIRCLE = "cupertino_ellipsis_vertical_circle"
    ELLIPSIS_VERTICAL_CIRCLE_FILL = "cupertino_ellipsis_vertical_circle_fill"
    ENVELOPE = "cupertino_envelope"
    ENVELOPE_BADGE = "cupertino_envelope_badge"
    ENVELOPE_BADGE_FILL = "cupertino_envelope_badge_fill"
    ENVELOPE_CIRCLE = "cupertino_envelope_circle"
    ENVELOPE_CIRCLE_FILL = "cupertino_envelope_circle_fill"
    ENVELOPE_FILL = "cupertino_envelope_fill"
    ENVELOPE_OPEN = "cupertino_envelope_open"
    ENVELOPE_OPEN_FILL = "cupertino_envelope_open_fill"
    EQUAL = "cupertino_equal"
    EQUAL_CIRCLE = "cupertino_equal_circle"
    EQUAL_CIRCLE_FILL = "cupertino_equal_circle_fill"
    EQUAL_SQUARE = "cupertino_equal_square"
    EQUAL_SQUARE_FILL = "cupertino_equal_square_fill"
    ESCAPE = "cupertino_escape"
    EXCLAMATIONMARK = "cupertino_exclamationmark"
    EXCLAMATIONMARK_BUBBLE = "cupertino_exclamationmark_bubble"
    EXCLAMATIONMARK_BUBBLE_FILL = "cupertino_exclamationmark_bubble_fill"
    EXCLAMATIONMARK_CIRCLE = "cupertino_exclamationmark_circle"
    EXCLAMATIONMARK_CIRCLE_FILL = "cupertino_exclamationmark_circle_fill"
    EXCLAMATIONMARK_OCTAGON = "cupertino_exclamationmark_octagon"
    EXCLAMATIONMARK_OCTAGON_FILL = "cupertino_exclamationmark_octagon_fill"
    EXCLAMATIONMARK_SHIELD = "cupertino_exclamationmark_shield"
    EXCLAMATIONMARK_SHIELD_FILL = "cupertino_exclamationmark_shield_fill"
    EXCLAMATIONMARK_SQUARE = "cupertino_exclamationmark_square"
    EXCLAMATIONMARK_SQUARE_FILL = "cupertino_exclamationmark_square_fill"
    EXCLAMATIONMARK_TRIANGLE = "cupertino_exclamationmark_triangle"
    EXCLAMATIONMARK_TRIANGLE_FILL = "cupertino_exclamationmark_triangle_fill"
    EYE_FILL = "cupertino_eye_fill"
    EYE_SLASH = "cupertino_eye_slash"
    EYE_SLASH_FILL = "cupertino_eye_slash_fill"
    EYEDROPPER = "cupertino_eyedropper"
    EYEDROPPER_FULL = "cupertino_eyedropper_full"
    EYEDROPPER_HALFFULL = "cupertino_eyedropper_halffull"
    EYEGLASSES = "cupertino_eyeglasses"
    F_CURSIVE = "cupertino_f_cursive"
    F_CURSIVE_CIRCLE = "cupertino_f_cursive_circle"
    F_CURSIVE_CIRCLE_FILL = "cupertino_f_cursive_circle_fill"
    FILM = "cupertino_film"
    FILM_FILL = "cupertino_film_fill"
    FLAG_CIRCLE = "cupertino_flag_circle"
    FLAG_CIRCLE_FILL = "cupertino_flag_circle_fill"
    FLAG_FILL = "cupertino_flag_fill"
    FLAG_SLASH = "cupertino_flag_slash"
    FLAG_SLASH_FILL = "cupertino_flag_slash_fill"
    FLAME = "cupertino_flame"
    FLAME_FILL = "cupertino_flame_fill"
    FLOPPY_DISK = "cupertino_floppy_disk"
    FLOWCHART = "cupertino_flowchart"
    FLOWCHART_FILL = "cupertino_flowchart_fill"
    FOLDER_BADGE_MINUS = "cupertino_folder_badge_minus"
    FOLDER_BADGE_PERSON_CROP = "cupertino_folder_badge_person_crop"
    FOLDER_BADGE_PLUS = "cupertino_folder_badge_plus"
    FOLDER_CIRCLE = "cupertino_folder_circle"
    FOLDER_CIRCLE_FILL = "cupertino_folder_circle_fill"
    FOLDER_FILL = "cupertino_folder_fill"
    FOLDER_FILL_BADGE_MINUS = "cupertino_folder_fill_badge_minus"
    FOLDER_FILL_BADGE_PERSON_CROP = "cupertino_folder_fill_badge_person_crop"
    FOLDER_FILL_BADGE_PLUS = "cupertino_folder_fill_badge_plus"
    FORWARD_END = "cupertino_forward_end"
    FORWARD_END_ALT = "cupertino_forward_end_alt"
    FORWARD_END_ALT_FILL = "cupertino_forward_end_alt_fill"
    FORWARD_END_FILL = "cupertino_forward_end_fill"
    FORWARD_FILL = "cupertino_forward_fill"
    FUNCTION = "cupertino_function"
    FX = "cupertino_fx"
    GAMECONTROLLER = "cupertino_gamecontroller"
    GAMECONTROLLER_ALT_FILL = "cupertino_gamecontroller_alt_fill"
    GAMECONTROLLER_FILL = "cupertino_gamecontroller_fill"
    GAUGE = "cupertino_gauge"
    GAUGE_BADGE_MINUS = "cupertino_gauge_badge_minus"
    GAUGE_BADGE_PLUS = "cupertino_gauge_badge_plus"
    GEAR_ALT = "cupertino_gear_alt"
    GEAR_ALT_FILL = "cupertino_gear_alt_fill"
    GIFT = "cupertino_gift"
    GIFT_ALT = "cupertino_gift_alt"
    GIFT_ALT_FILL = "cupertino_gift_alt_fill"
    GIFT_FILL = "cupertino_gift_fill"
    GLOBE = "cupertino_globe"
    GOBACKWARD = "cupertino_gobackward"
    GOBACKWARD_10 = "cupertino_gobackward_10"
    GOBACKWARD_15 = "cupertino_gobackward_15"
    GOBACKWARD_30 = "cupertino_gobackward_30"
    GOBACKWARD_45 = "cupertino_gobackward_45"
    GOBACKWARD_60 = "cupertino_gobackward_60"
    GOBACKWARD_75 = "cupertino_gobackward_75"
    GOBACKWARD_90 = "cupertino_gobackward_90"
    GOBACKWARD_MINUS = "cupertino_gobackward_minus"
    GOFORWARD = "cupertino_goforward"
    GOFORWARD_10 = "cupertino_goforward_10"
    GOFORWARD_15 = "cupertino_goforward_15"
    GOFORWARD_30 = "cupertino_goforward_30"
    GOFORWARD_45 = "cupertino_goforward_45"
    GOFORWARD_60 = "cupertino_goforward_60"
    GOFORWARD_75 = "cupertino_goforward_75"
    GOFORWARD_90 = "cupertino_goforward_90"
    GOFORWARD_PLUS = "cupertino_goforward_plus"
    GRAPH_CIRCLE = "cupertino_graph_circle"
    GRAPH_CIRCLE_FILL = "cupertino_graph_circle_fill"
    GRAPH_SQUARE = "cupertino_graph_square"
    GRAPH_SQUARE_FILL = "cupertino_graph_square_fill"
    GREATERTHAN = "cupertino_greaterthan"
    GREATERTHAN_CIRCLE = "cupertino_greaterthan_circle"
    GREATERTHAN_CIRCLE_FILL = "cupertino_greaterthan_circle_fill"
    GREATERTHAN_SQUARE = "cupertino_greaterthan_square"
    GREATERTHAN_SQUARE_FILL = "cupertino_greaterthan_square_fill"
    GRID = "cupertino_grid"
    GRID_CIRCLE = "cupertino_grid_circle"
    GRID_CIRCLE_FILL = "cupertino_grid_circle_fill"
    GUITARS = "cupertino_guitars"
    HAMMER = "cupertino_hammer"
    HAMMER_FILL = "cupertino_hammer_fill"
    HAND_DRAW = "cupertino_hand_draw"
    HAND_DRAW_FILL = "cupertino_hand_draw_fill"
    HAND_POINT_LEFT = "cupertino_hand_point_left"
    HAND_POINT_LEFT_FILL = "cupertino_hand_point_left_fill"
    HAND_POINT_RIGHT = "cupertino_hand_point_right"
    HAND_POINT_RIGHT_FILL = "cupertino_hand_point_right_fill"
    HAND_RAISED = "cupertino_hand_raised"
    HAND_RAISED_FILL = "cupertino_hand_raised_fill"
    HAND_RAISED_SLASH = "cupertino_hand_raised_slash"
    HAND_RAISED_SLASH_FILL = "cupertino_hand_raised_slash_fill"
    HAND_THUMBSDOWN = "cupertino_hand_thumbsdown"
    HAND_THUMBSDOWN_FILL = "cupertino_hand_thumbsdown_fill"
    HAND_THUMBSUP = "cupertino_hand_thumbsup"
    HAND_THUMBSUP_FILL = "cupertino_hand_thumbsup_fill"
    HARE = "cupertino_hare"
    HARE_FILL = "cupertino_hare_fill"
    HEADPHONES = "cupertino_headphones"
    HEART_CIRCLE = "cupertino_heart_circle"
    HEART_CIRCLE_FILL = "cupertino_heart_circle_fill"
    HEART_FILL = "cupertino_heart_fill"
    HEART_SLASH = "cupertino_heart_slash"
    HEART_SLASH_CIRCLE = "cupertino_heart_slash_circle"
    HEART_SLASH_CIRCLE_FILL = "cupertino_heart_slash_circle_fill"
    HEART_SLASH_FILL = "cupertino_heart_slash_fill"
    HELM = "cupertino_helm"
    HEXAGON = "cupertino_hexagon"
    HEXAGON_FILL = "cupertino_hexagon_fill"
    HIFISPEAKER = "cupertino_hifispeaker"
    HIFISPEAKER_FILL = "cupertino_hifispeaker_fill"
    HOURGLASS = "cupertino_hourglass"
    HOURGLASS_BOTTOMHALF_FILL = "cupertino_hourglass_bottomhalf_fill"
    HOURGLASS_TOPHALF_FILL = "cupertino_hourglass_tophalf_fill"
    HOUSE = "cupertino_house"
    HOUSE_ALT = "cupertino_house_alt"
    HOUSE_ALT_FILL = "cupertino_house_alt_fill"
    HOUSE_FILL = "cupertino_house_fill"
    HURRICANE = "cupertino_hurricane"
    INCREASE_INDENT = "cupertino_increase_indent"
    INCREASE_QUOTELEVEL = "cupertino_increase_quotelevel"
    INFINITE = "cupertino_infinite"
    INFO_CIRCLE = "cupertino_info_circle"
    INFO_CIRCLE_FILL = "cupertino_info_circle_fill"
    ITALIC = "cupertino_italic"
    KEYBOARD = "cupertino_keyboard"
    KEYBOARD_CHEVRON_COMPACT_DOWN = "cupertino_keyboard_chevron_compact_down"
    LARGECIRCLE_FILL_CIRCLE = "cupertino_largecircle_fill_circle"
    LASSO = "cupertino_lasso"
    LAYERS = "cupertino_layers"
    LAYERS_ALT = "cupertino_layers_alt"
    LAYERS_ALT_FILL = "cupertino_layers_alt_fill"
    LAYERS_FILL = "cupertino_layers_fill"
    LEAF_ARROW_CIRCLEPATH = "cupertino_leaf_arrow_circlepath"
    LESSTHAN = "cupertino_lessthan"
    LESSTHAN_CIRCLE = "cupertino_lessthan_circle"
    LESSTHAN_CIRCLE_FILL = "cupertino_lessthan_circle_fill"
    LESSTHAN_SQUARE = "cupertino_lessthan_square"
    LESSTHAN_SQUARE_FILL = "cupertino_lessthan_square_fill"
    LIGHT_MAX = "cupertino_light_max"
    LIGHT_MIN = "cupertino_light_min"
    LIGHTBULB = "cupertino_lightbulb"
    LIGHTBULB_FILL = "cupertino_lightbulb_fill"
    LIGHTBULB_SLASH = "cupertino_lightbulb_slash"
    LIGHTBULB_SLASH_FILL = "cupertino_lightbulb_slash_fill"
    LINE_HORIZONTAL_3 = "cupertino_line_horizontal_3"
    LINE_HORIZONTAL_3_DECREASE = "cupertino_line_horizontal_3_decrease"
    LINE_HORIZONTAL_3_DECREASE_CIRCLE = "cupertino_line_horizontal_3_decrease_circle"
    LINE_HORIZONTAL_3_DECREASE_CIRCLE_FILL = (
        "cupertino_line_horizontal_3_decrease_circle_fill"
    )
    LINK = "cupertino_link"
    LINK_CIRCLE = "cupertino_link_circle"
    LINK_CIRCLE_FILL = "cupertino_link_circle_fill"
    LIST_BULLET = "cupertino_list_bullet"
    LIST_BULLET_BELOW_RECTANGLE = "cupertino_list_bullet_below_rectangle"
    LIST_BULLET_INDENT = "cupertino_list_bullet_indent"
    LIST_DASH = "cupertino_list_dash"
    LIST_NUMBER = "cupertino_list_number"
    LIST_NUMBER_RTL = "cupertino_list_number_rtl"
    LOCATION_CIRCLE = "cupertino_location_circle"
    LOCATION_CIRCLE_FILL = "cupertino_location_circle_fill"
    LOCATION_FILL = "cupertino_location_fill"
    LOCATION_NORTH = "cupertino_location_north"
    LOCATION_NORTH_FILL = "cupertino_location_north_fill"
    LOCATION_NORTH_LINE = "cupertino_location_north_line"
    LOCATION_NORTH_LINE_FILL = "cupertino_location_north_line_fill"
    LOCATION_SLASH = "cupertino_location_slash"
    LOCATION_SLASH_FILL = "cupertino_location_slash_fill"
    LOCK = "cupertino_lock"
    LOCK_CIRCLE = "cupertino_lock_circle"
    LOCK_CIRCLE_FILL = "cupertino_lock_circle_fill"
    LOCK_FILL = "cupertino_lock_fill"
    LOCK_OPEN = "cupertino_lock_open"
    LOCK_OPEN_FILL = "cupertino_lock_open_fill"
    LOCK_ROTATION = "cupertino_lock_rotation"
    LOCK_ROTATION_OPEN = "cupertino_lock_rotation_open"
    LOCK_SHIELD = "cupertino_lock_shield"
    LOCK_SHIELD_FILL = "cupertino_lock_shield_fill"
    LOCK_SLASH = "cupertino_lock_slash"
    LOCK_SLASH_FILL = "cupertino_lock_slash_fill"
    MACWINDOW = "cupertino_macwindow"
    MAP = "cupertino_map"
    MAP_FILL = "cupertino_map_fill"
    MAP_PIN = "cupertino_map_pin"
    MAP_PIN_ELLIPSE = "cupertino_map_pin_ellipse"
    MAP_PIN_SLASH = "cupertino_map_pin_slash"
    MEMORIES = "cupertino_memories"
    MEMORIES_BADGE_MINUS = "cupertino_memories_badge_minus"
    MEMORIES_BADGE_PLUS = "cupertino_memories_badge_plus"
    METRONOME = "cupertino_metronome"
    MIC_CIRCLE = "cupertino_mic_circle"
    MIC_CIRCLE_FILL = "cupertino_mic_circle_fill"
    MIC_FILL = "cupertino_mic_fill"
    MIC_SLASH = "cupertino_mic_slash"
    MIC_SLASH_FILL = "cupertino_mic_slash_fill"
    MINUS = "cupertino_minus"
    MINUS_CIRCLE = "cupertino_minus_circle"
    MINUS_CIRCLE_FILL = "cupertino_minus_circle_fill"
    MINUS_RECTANGLE = "cupertino_minus_rectangle"
    MINUS_RECTANGLE_FILL = "cupertino_minus_rectangle_fill"
    MINUS_SLASH_PLUS = "cupertino_minus_slash_plus"
    MINUS_SQUARE = "cupertino_minus_square"
    MINUS_SQUARE_FILL = "cupertino_minus_square_fill"
    MONEY_DOLLAR = "cupertino_money_dollar"
    MONEY_DOLLAR_CIRCLE = "cupertino_money_dollar_circle"
    MONEY_DOLLAR_CIRCLE_FILL = "cupertino_money_dollar_circle_fill"
    MONEY_EURO = "cupertino_money_euro"
    MONEY_EURO_CIRCLE = "cupertino_money_euro_circle"
    MONEY_EURO_CIRCLE_FILL = "cupertino_money_euro_circle_fill"
    MONEY_POUND = "cupertino_money_pound"
    MONEY_POUND_CIRCLE = "cupertino_money_pound_circle"
    MONEY_POUND_CIRCLE_FILL = "cupertino_money_pound_circle_fill"
    MONEY_RUBL = "cupertino_money_rubl"
    MONEY_RUBL_CIRCLE = "cupertino_money_rubl_circle"
    MONEY_RUBL_CIRCLE_FILL = "cupertino_money_rubl_circle_fill"
    MONEY_YEN = "cupertino_money_yen"
    MONEY_YEN_CIRCLE = "cupertino_money_yen_circle"
    MONEY_YEN_CIRCLE_FILL = "cupertino_money_yen_circle_fill"
    MOON = "cupertino_moon"
    MOON_CIRCLE = "cupertino_moon_circle"
    MOON_CIRCLE_FILL = "cupertino_moon_circle_fill"
    MOON_FILL = "cupertino_moon_fill"
    MOON_STARS = "cupertino_moon_stars"
    MOON_STARS_FILL = "cupertino_moon_stars_fill"
    MOON_ZZZ = "cupertino_moon_zzz"
    MOON_ZZZ_FILL = "cupertino_moon_zzz_fill"
    MOVE = "cupertino_move"
    MULTIPLY = "cupertino_multiply"
    MULTIPLY_CIRCLE = "cupertino_multiply_circle"
    MULTIPLY_CIRCLE_FILL = "cupertino_multiply_circle_fill"
    MULTIPLY_SQUARE = "cupertino_multiply_square"
    MULTIPLY_SQUARE_FILL = "cupertino_multiply_square_fill"
    MUSIC_ALBUMS = "cupertino_music_albums"
    MUSIC_ALBUMS_FILL = "cupertino_music_albums_fill"
    MUSIC_HOUSE = "cupertino_music_house"
    MUSIC_HOUSE_FILL = "cupertino_music_house_fill"
    MUSIC_MIC = "cupertino_music_mic"
    MUSIC_NOTE_2 = "cupertino_music_note_2"
    MUSIC_NOTE_LIST = "cupertino_music_note_list"
    NOSIGN = "cupertino_nosign"
    NUMBER = "cupertino_number"
    NUMBER_CIRCLE = "cupertino_number_circle"
    NUMBER_CIRCLE_FILL = "cupertino_number_circle_fill"
    NUMBER_SQUARE = "cupertino_number_square"
    NUMBER_SQUARE_FILL = "cupertino_number_square_fill"
    OPTION = "cupertino_option"
    PAINTBRUSH = "cupertino_paintbrush"
    PAINTBRUSH_FILL = "cupertino_paintbrush_fill"
    PANO = "cupertino_pano"
    PANO_FILL = "cupertino_pano_fill"
    PAPERCLIP = "cupertino_paperclip"
    PAPERPLANE = "cupertino_paperplane"
    PAPERPLANE_FILL = "cupertino_paperplane_fill"
    PARAGRAPH = "cupertino_paragraph"
    PAUSE_CIRCLE = "cupertino_pause_circle"
    PAUSE_CIRCLE_FILL = "cupertino_pause_circle_fill"
    PAUSE_FILL = "cupertino_pause_fill"
    PAUSE_RECTANGLE = "cupertino_pause_rectangle"
    PAUSE_RECTANGLE_FILL = "cupertino_pause_rectangle_fill"
    PENCIL_CIRCLE = "cupertino_pencil_circle"
    PENCIL_CIRCLE_FILL = "cupertino_pencil_circle_fill"
    PENCIL_ELLIPSIS_RECTANGLE = "cupertino_pencil_ellipsis_rectangle"
    PENCIL_OUTLINE = "cupertino_pencil_outline"
    PENCIL_SLASH = "cupertino_pencil_slash"
    PERCENT = "cupertino_percent"
    PERSON_2 = "cupertino_person_2"
    PERSON_2_ALT = "cupertino_person_2_alt"
    PERSON_2_FILL = "cupertino_person_2_fill"
    PERSON_2_SQUARE_STACK = "cupertino_person_2_square_stack"
    PERSON_2_SQUARE_STACK_FILL = "cupertino_person_2_square_stack_fill"
    PERSON_3 = "cupertino_person_3"
    PERSON_3_FILL = "cupertino_person_3_fill"
    PERSON_ALT = "cupertino_person_alt"
    PERSON_ALT_CIRCLE = "cupertino_person_alt_circle"
    PERSON_ALT_CIRCLE_FILL = "cupertino_person_alt_circle_fill"
    PERSON_BADGE_MINUS = "cupertino_person_badge_minus"
    PERSON_BADGE_MINUS_FILL = "cupertino_person_badge_minus_fill"
    PERSON_BADGE_PLUS = "cupertino_person_badge_plus"
    PERSON_BADGE_PLUS_FILL = "cupertino_person_badge_plus_fill"
    PERSON_CIRCLE = "cupertino_person_circle"
    PERSON_CIRCLE_FILL = "cupertino_person_circle_fill"
    PERSON_CROP_CIRCLE = "cupertino_person_crop_circle"
    PERSON_CROP_CIRCLE_BADGE_CHECKMARK = "cupertino_person_crop_circle_badge_checkmark"
    PERSON_CROP_CIRCLE_BADGE_EXCLAM = "cupertino_person_crop_circle_badge_exclam"
    PERSON_CROP_CIRCLE_BADGE_MINUS = "cupertino_person_crop_circle_badge_minus"
    PERSON_CROP_CIRCLE_BADGE_PLUS = "cupertino_person_crop_circle_badge_plus"
    PERSON_CROP_CIRCLE_BADGE_XMARK = "cupertino_person_crop_circle_badge_xmark"
    PERSON_CROP_CIRCLE_FILL = "cupertino_person_crop_circle_fill"
    PERSON_CROP_CIRCLE_FILL_BADGE_CHECKMARK = (
        "cupertino_person_crop_circle_fill_badge_checkmark"
    )
    PERSON_CROP_CIRCLE_FILL_BADGE_EXCLAM = (
        "cupertino_person_crop_circle_fill_badge_exclam"
    )
    PERSON_CROP_CIRCLE_FILL_BADGE_MINUS = (
        "cupertino_person_crop_circle_fill_badge_minus"
    )
    PERSON_CROP_CIRCLE_FILL_BADGE_PLUS = "cupertino_person_crop_circle_fill_badge_plus"
    PERSON_CROP_CIRCLE_FILL_BADGE_XMARK = (
        "cupertino_person_crop_circle_fill_badge_xmark"
    )
    PERSON_CROP_RECTANGLE = "cupertino_person_crop_rectangle"
    PERSON_CROP_RECTANGLE_FILL = "cupertino_person_crop_rectangle_fill"
    PERSON_CROP_SQUARE = "cupertino_person_crop_square"
    PERSON_CROP_SQUARE_FILL = "cupertino_person_crop_square_fill"
    PERSON_FILL = "cupertino_person_fill"
    PERSONALHOTSPOT = "cupertino_personalhotspot"
    PERSPECTIVE = "cupertino_perspective"
    PHONE_ARROW_DOWN_LEFT = "cupertino_phone_arrow_down_left"
    PHONE_ARROW_RIGHT = "cupertino_phone_arrow_right"
    PHONE_ARROW_UP_RIGHT = "cupertino_phone_arrow_up_right"
    PHONE_BADGE_PLUS = "cupertino_phone_badge_plus"
    PHONE_CIRCLE = "cupertino_phone_circle"
    PHONE_CIRCLE_FILL = "cupertino_phone_circle_fill"
    PHONE_DOWN = "cupertino_phone_down"
    PHONE_DOWN_CIRCLE = "cupertino_phone_down_circle"
    PHONE_DOWN_CIRCLE_FILL = "cupertino_phone_down_circle_fill"
    PHONE_DOWN_FILL = "cupertino_phone_down_fill"
    PHONE_FILL = "cupertino_phone_fill"
    PHONE_FILL_ARROW_DOWN_LEFT = "cupertino_phone_fill_arrow_down_left"
    PHONE_FILL_ARROW_RIGHT = "cupertino_phone_fill_arrow_right"
    PHONE_FILL_ARROW_UP_RIGHT = "cupertino_phone_fill_arrow_up_right"
    PHONE_FILL_BADGE_PLUS = "cupertino_phone_fill_badge_plus"
    PHOTO = "cupertino_photo"
    PHOTO_FILL = "cupertino_photo_fill"
    PHOTO_FILL_ON_RECTANGLE_FILL = "cupertino_photo_fill_on_rectangle_fill"
    PHOTO_ON_RECTANGLE = "cupertino_photo_on_rectangle"
    PIANO = "cupertino_piano"
    PIN = "cupertino_pin"
    PIN_FILL = "cupertino_pin_fill"
    PIN_SLASH = "cupertino_pin_slash"
    PIN_SLASH_FILL = "cupertino_pin_slash_fill"
    PLACEMARK = "cupertino_placemark"
    PLACEMARK_FILL = "cupertino_placemark_fill"
    PLAY = "cupertino_play"
    PLAY_CIRCLE = "cupertino_play_circle"
    PLAY_CIRCLE_FILL = "cupertino_play_circle_fill"
    PLAY_FILL = "cupertino_play_fill"
    PLAY_RECTANGLE = "cupertino_play_rectangle"
    PLAY_RECTANGLE_FILL = "cupertino_play_rectangle_fill"
    PLAYPAUSE = "cupertino_playpause"
    PLAYPAUSE_FILL = "cupertino_playpause_fill"
    PLUS = "cupertino_plus"
    PLUS_APP = "cupertino_plus_app"
    PLUS_APP_FILL = "cupertino_plus_app_fill"
    PLUS_BUBBLE = "cupertino_plus_bubble"
    PLUS_BUBBLE_FILL = "cupertino_plus_bubble_fill"
    PLUS_CIRCLE = "cupertino_plus_circle"
    PLUS_CIRCLE_FILL = "cupertino_plus_circle_fill"
    PLUS_RECTANGLE = "cupertino_plus_rectangle"
    PLUS_RECTANGLE_FILL = "cupertino_plus_rectangle_fill"
    PLUS_RECTANGLE_FILL_ON_RECTANGLE_FILL = (
        "cupertino_plus_rectangle_fill_on_rectangle_fill"
    )
    PLUS_RECTANGLE_ON_RECTANGLE = "cupertino_plus_rectangle_on_rectangle"
    PLUS_SLASH_MINUS = "cupertino_plus_slash_minus"
    PLUS_SQUARE = "cupertino_plus_square"
    PLUS_SQUARE_FILL = "cupertino_plus_square_fill"
    PLUS_SQUARE_FILL_ON_SQUARE_FILL = "cupertino_plus_square_fill_on_square_fill"
    PLUS_SQUARE_ON_SQUARE = "cupertino_plus_square_on_square"
    PLUSMINUS = "cupertino_plusminus"
    PLUSMINUS_CIRCLE = "cupertino_plusminus_circle"
    PLUSMINUS_CIRCLE_FILL = "cupertino_plusminus_circle_fill"
    POWER = "cupertino_power"
    PRINTER = "cupertino_printer"
    PRINTER_FILL = "cupertino_printer_fill"
    PROJECTIVE = "cupertino_projective"
    PURCHASED = "cupertino_purchased"
    PURCHASED_CIRCLE = "cupertino_purchased_circle"
    PURCHASED_CIRCLE_FILL = "cupertino_purchased_circle_fill"
    QRCODE = "cupertino_qrcode"
    QRCODE_VIEWFINDER = "cupertino_qrcode_viewfinder"
    QUESTION = "cupertino_question"
    QUESTION_CIRCLE = "cupertino_question_circle"
    QUESTION_CIRCLE_FILL = "cupertino_question_circle_fill"
    QUESTION_DIAMOND = "cupertino_question_diamond"
    QUESTION_DIAMOND_FILL = "cupertino_question_diamond_fill"
    QUESTION_SQUARE = "cupertino_question_square"
    QUESTION_SQUARE_FILL = "cupertino_question_square_fill"
    QUOTE_BUBBLE = "cupertino_quote_bubble"
    QUOTE_BUBBLE_FILL = "cupertino_quote_bubble_fill"
    RADIOWAVES_LEFT = "cupertino_radiowaves_left"
    RADIOWAVES_RIGHT = "cupertino_radiowaves_right"
    RAYS = "cupertino_rays"
    RECORDINGTAPE = "cupertino_recordingtape"
    RECTANGLE = "cupertino_rectangle"
    RECTANGLE_3_OFFGRID = "cupertino_rectangle_3_offgrid"
    RECTANGLE_3_OFFGRID_FILL = "cupertino_rectangle_3_offgrid_fill"
    RECTANGLE_ARROW_UP_RIGHT_ARROW_DOWN_LEFT = (
        "cupertino_rectangle_arrow_up_right_arrow_down_left"
    )
    RECTANGLE_ARROW_UP_RIGHT_ARROW_DOWN_LEFT_SLASH = (
        "cupertino_rectangle_arrow_up_right_arrow_down_left_slash"
    )
    RECTANGLE_BADGE_CHECKMARK = "cupertino_rectangle_badge_checkmark"
    RECTANGLE_BADGE_XMARK = "cupertino_rectangle_badge_xmark"
    RECTANGLE_COMPRESS_VERTICAL = "cupertino_rectangle_compress_vertical"
    RECTANGLE_DOCK = "cupertino_rectangle_dock"
    RECTANGLE_EXPAND_VERTICAL = "cupertino_rectangle_expand_vertical"
    RECTANGLE_FILL = "cupertino_rectangle_fill"
    RECTANGLE_FILL_BADGE_CHECKMARK = "cupertino_rectangle_fill_badge_checkmark"
    RECTANGLE_FILL_BADGE_XMARK = "cupertino_rectangle_fill_badge_xmark"
    RECTANGLE_FILL_ON_RECTANGLE_ANGLED_FILL = (
        "cupertino_rectangle_fill_on_rectangle_angled_fill"
    )
    RECTANGLE_FILL_ON_RECTANGLE_FILL = "cupertino_rectangle_fill_on_rectangle_fill"
    RECTANGLE_GRID_1X2 = "cupertino_rectangle_grid_1x2"
    RECTANGLE_GRID_1X2_FILL = "cupertino_rectangle_grid_1x2_fill"
    RECTANGLE_GRID_2X2 = "cupertino_rectangle_grid_2x2"
    RECTANGLE_GRID_2X2_FILL = "cupertino_rectangle_grid_2x2_fill"
    RECTANGLE_GRID_3X2 = "cupertino_rectangle_grid_3x2"
    RECTANGLE_GRID_3X2_FILL = "cupertino_rectangle_grid_3x2_fill"
    RECTANGLE_ON_RECTANGLE = "cupertino_rectangle_on_rectangle"
    RECTANGLE_ON_RECTANGLE_ANGLED = "cupertino_rectangle_on_rectangle_angled"
    RECTANGLE_PAPERCLIP = "cupertino_rectangle_paperclip"
    RECTANGLE_SPLIT_3X1 = "cupertino_rectangle_split_3x1"
    RECTANGLE_SPLIT_3X1_FILL = "cupertino_rectangle_split_3x1_fill"
    RECTANGLE_SPLIT_3X3 = "cupertino_rectangle_split_3x3"
    RECTANGLE_SPLIT_3X3_FILL = "cupertino_rectangle_split_3x3_fill"
    RECTANGLE_STACK = "cupertino_rectangle_stack"
    RECTANGLE_STACK_BADGE_MINUS = "cupertino_rectangle_stack_badge_minus"
    RECTANGLE_STACK_BADGE_PERSON_CROP = "cupertino_rectangle_stack_badge_person_crop"
    RECTANGLE_STACK_BADGE_PLUS = "cupertino_rectangle_stack_badge_plus"
    RECTANGLE_STACK_FILL = "cupertino_rectangle_stack_fill"
    RECTANGLE_STACK_FILL_BADGE_MINUS = "cupertino_rectangle_stack_fill_badge_minus"
    RECTANGLE_STACK_FILL_BADGE_PERSON_CROP = (
        "cupertino_rectangle_stack_fill_badge_person_crop"
    )
    RECTANGLE_STACK_FILL_BADGE_PLUS = "cupertino_rectangle_stack_fill_badge_plus"
    RECTANGLE_STACK_PERSON_CROP = "cupertino_rectangle_stack_person_crop"
    RECTANGLE_STACK_PERSON_CROP_FILL = "cupertino_rectangle_stack_person_crop_fill"
    REPEAT = "cupertino_repeat"
    REPEAT_1 = "cupertino_repeat_1"
    RESIZE = "cupertino_resize"
    RESIZE_H = "cupertino_resize_h"
    RESIZE_V = "cupertino_resize_v"
    RETURN_ICON = "cupertino_return_icon"
    RHOMBUS = "cupertino_rhombus"
    RHOMBUS_FILL = "cupertino_rhombus_fill"
    ROCKET = "cupertino_rocket"
    ROCKET_FILL = "cupertino_rocket_fill"
    ROSETTE = "cupertino_rosette"
    ROTATE_LEFT = "cupertino_rotate_left"
    ROTATE_LEFT_FILL = "cupertino_rotate_left_fill"
    ROTATE_RIGHT = "cupertino_rotate_right"
    ROTATE_RIGHT_FILL = "cupertino_rotate_right_fill"
    SCISSORS = "cupertino_scissors"
    SCISSORS_ALT = "cupertino_scissors_alt"
    SCOPE = "cupertino_scope"
    SCRIBBLE = "cupertino_scribble"
    SEARCH_CIRCLE = "cupertino_search_circle"
    SEARCH_CIRCLE_FILL = "cupertino_search_circle_fill"
    SELECTION_PIN_IN_OUT = "cupertino_selection_pin_in_out"
    SHIELD = "cupertino_shield"
    SHIELD_FILL = "cupertino_shield_fill"
    SHIELD_LEFTHALF_FILL = "cupertino_shield_lefthalf_fill"
    SHIELD_SLASH = "cupertino_shield_slash"
    SHIELD_SLASH_FILL = "cupertino_shield_slash_fill"
    SHIFT = "cupertino_shift"
    SHIFT_FILL = "cupertino_shift_fill"
    SIDEBAR_LEFT = "cupertino_sidebar_left"
    SIDEBAR_RIGHT = "cupertino_sidebar_right"
    SIGNATURE = "cupertino_signature"
    SKEW = "cupertino_skew"
    SLASH_CIRCLE = "cupertino_slash_circle"
    SLASH_CIRCLE_FILL = "cupertino_slash_circle_fill"
    SLIDER_HORIZONTAL_3 = "cupertino_slider_horizontal_3"
    SLIDER_HORIZONTAL_BELOW_RECTANGLE = "cupertino_slider_horizontal_below_rectangle"
    SLOWMO = "cupertino_slowmo"
    SMALLCIRCLE_CIRCLE = "cupertino_smallcircle_circle"
    SMALLCIRCLE_CIRCLE_FILL = "cupertino_smallcircle_circle_fill"
    SMALLCIRCLE_FILL_CIRCLE = "cupertino_smallcircle_fill_circle"
    SMALLCIRCLE_FILL_CIRCLE_FILL = "cupertino_smallcircle_fill_circle_fill"
    SMILEY = "cupertino_smiley"
    SMILEY_FILL = "cupertino_smiley_fill"
    SMOKE = "cupertino_smoke"
    SMOKE_FILL = "cupertino_smoke_fill"
    SNOW = "cupertino_snow"
    SORT_DOWN = "cupertino_sort_down"
    SORT_DOWN_CIRCLE = "cupertino_sort_down_circle"
    SORT_DOWN_CIRCLE_FILL = "cupertino_sort_down_circle_fill"
    SORT_UP = "cupertino_sort_up"
    SORT_UP_CIRCLE = "cupertino_sort_up_circle"
    SORT_UP_CIRCLE_FILL = "cupertino_sort_up_circle_fill"
    SPARKLES = "cupertino_sparkles"
    SPEAKER = "cupertino_speaker"
    SPEAKER_1 = "cupertino_speaker_1"
    SPEAKER_1_FILL = "cupertino_speaker_1_fill"
    SPEAKER_2 = "cupertino_speaker_2"
    SPEAKER_2_FILL = "cupertino_speaker_2_fill"
    SPEAKER_3 = "cupertino_speaker_3"
    SPEAKER_3_FILL = "cupertino_speaker_3_fill"
    SPEAKER_FILL = "cupertino_speaker_fill"
    SPEAKER_SLASH = "cupertino_speaker_slash"
    SPEAKER_SLASH_FILL = "cupertino_speaker_slash_fill"
    SPEAKER_SLASH_FILL_RTL = "cupertino_speaker_slash_fill_rtl"
    SPEAKER_SLASH_RTL = "cupertino_speaker_slash_rtl"
    SPEAKER_ZZZ = "cupertino_speaker_zzz"
    SPEAKER_ZZZ_FILL = "cupertino_speaker_zzz_fill"
    SPEAKER_ZZZ_FILL_RTL = "cupertino_speaker_zzz_fill_rtl"
    SPEAKER_ZZZ_RTL = "cupertino_speaker_zzz_rtl"
    SPEEDOMETER = "cupertino_speedometer"
    SPORTSCOURT = "cupertino_sportscourt"
    SPORTSCOURT_FILL = "cupertino_sportscourt_fill"
    SQUARE = "cupertino_square"
    SQUARE_ARROW_DOWN = "cupertino_square_arrow_down"
    SQUARE_ARROW_DOWN_FILL = "cupertino_square_arrow_down_fill"
    SQUARE_ARROW_DOWN_ON_SQUARE = "cupertino_square_arrow_down_on_square"
    SQUARE_ARROW_DOWN_ON_SQUARE_FILL = "cupertino_square_arrow_down_on_square_fill"
    SQUARE_ARROW_LEFT = "cupertino_square_arrow_left"
    SQUARE_ARROW_LEFT_FILL = "cupertino_square_arrow_left_fill"
    SQUARE_ARROW_RIGHT = "cupertino_square_arrow_right"
    SQUARE_ARROW_RIGHT_FILL = "cupertino_square_arrow_right_fill"
    SQUARE_ARROW_UP = "cupertino_square_arrow_up"
    SQUARE_ARROW_UP_FILL = "cupertino_square_arrow_up_fill"
    SQUARE_ARROW_UP_ON_SQUARE = "cupertino_square_arrow_up_on_square"
    SQUARE_ARROW_UP_ON_SQUARE_FILL = "cupertino_square_arrow_up_on_square_fill"
    SQUARE_FAVORITES = "cupertino_square_favorites"
    SQUARE_FAVORITES_ALT = "cupertino_square_favorites_alt"
    SQUARE_FAVORITES_ALT_FILL = "cupertino_square_favorites_alt_fill"
    SQUARE_FAVORITES_FILL = "cupertino_square_favorites_fill"
    SQUARE_FILL = "cupertino_square_fill"
    SQUARE_FILL_LINE_VERTICAL_SQUARE = "cupertino_square_fill_line_vertical_square"
    SQUARE_FILL_LINE_VERTICAL_SQUARE_FILL = (
        "cupertino_square_fill_line_vertical_square_fill"
    )
    SQUARE_FILL_ON_CIRCLE_FILL = "cupertino_square_fill_on_circle_fill"
    SQUARE_FILL_ON_SQUARE_FILL = "cupertino_square_fill_on_square_fill"
    SQUARE_GRID_2X2 = "cupertino_square_grid_2x2"
    SQUARE_GRID_2X2_FILL = "cupertino_square_grid_2x2_fill"
    SQUARE_GRID_3X2 = "cupertino_square_grid_3x2"
    SQUARE_GRID_3X2_FILL = "cupertino_square_grid_3x2_fill"
    SQUARE_GRID_4X3_FILL = "cupertino_square_grid_4x3_fill"
    SQUARE_LEFTHALF_FILL = "cupertino_square_lefthalf_fill"
    SQUARE_LINE_VERTICAL_SQUARE = "cupertino_square_line_vertical_square"
    SQUARE_LINE_VERTICAL_SQUARE_FILL = "cupertino_square_line_vertical_square_fill"
    SQUARE_LIST = "cupertino_square_list"
    SQUARE_LIST_FILL = "cupertino_square_list_fill"
    SQUARE_ON_CIRCLE = "cupertino_square_on_circle"
    SQUARE_ON_SQUARE = "cupertino_square_on_square"
    SQUARE_PENCIL = "cupertino_square_pencil"
    SQUARE_PENCIL_FILL = "cupertino_square_pencil_fill"
    SQUARE_RIGHTHALF_FILL = "cupertino_square_righthalf_fill"
    SQUARE_SPLIT_1X2 = "cupertino_square_split_1x2"
    SQUARE_SPLIT_1X2_FILL = "cupertino_square_split_1x2_fill"
    SQUARE_SPLIT_2X1 = "cupertino_square_split_2x1"
    SQUARE_SPLIT_2X1_FILL = "cupertino_square_split_2x1_fill"
    SQUARE_SPLIT_2X2 = "cupertino_square_split_2x2"
    SQUARE_SPLIT_2X2_FILL = "cupertino_square_split_2x2_fill"
    SQUARE_STACK = "cupertino_square_stack"
    SQUARE_STACK_3D_DOWN_DOTTEDLINE = "cupertino_square_stack_3d_down_dottedline"
    SQUARE_STACK_3D_DOWN_RIGHT = "cupertino_square_stack_3d_down_right"
    SQUARE_STACK_3D_DOWN_RIGHT_FILL = "cupertino_square_stack_3d_down_right_fill"
    SQUARE_STACK_3D_UP = "cupertino_square_stack_3d_up"
    SQUARE_STACK_3D_UP_FILL = "cupertino_square_stack_3d_up_fill"
    SQUARE_STACK_3D_UP_SLASH = "cupertino_square_stack_3d_up_slash"
    SQUARE_STACK_3D_UP_SLASH_FILL = "cupertino_square_stack_3d_up_slash_fill"
    SQUARE_STACK_FILL = "cupertino_square_stack_fill"
    SQUARES_BELOW_RECTANGLE = "cupertino_squares_below_rectangle"
    STAR = "cupertino_star"
    STAR_CIRCLE = "cupertino_star_circle"
    STAR_CIRCLE_FILL = "cupertino_star_circle_fill"
    STAR_FILL = "cupertino_star_fill"
    STAR_LEFTHALF_FILL = "cupertino_star_lefthalf_fill"
    STAR_SLASH = "cupertino_star_slash"
    STAR_SLASH_FILL = "cupertino_star_slash_fill"
    STAROFLIFE = "cupertino_staroflife"
    STAROFLIFE_FILL = "cupertino_staroflife_fill"
    STOP = "cupertino_stop"
    STOP_CIRCLE = "cupertino_stop_circle"
    STOP_CIRCLE_FILL = "cupertino_stop_circle_fill"
    STOP_FILL = "cupertino_stop_fill"
    STOPWATCH = "cupertino_stopwatch"
    STOPWATCH_FILL = "cupertino_stopwatch_fill"
    STRIKETHROUGH = "cupertino_strikethrough"
    SUIT_CLUB = "cupertino_suit_club"
    SUIT_CLUB_FILL = "cupertino_suit_club_fill"
    SUIT_DIAMOND = "cupertino_suit_diamond"
    SUIT_DIAMOND_FILL = "cupertino_suit_diamond_fill"
    SUIT_HEART = "cupertino_suit_heart"
    SUIT_HEART_FILL = "cupertino_suit_heart_fill"
    SUIT_SPADE = "cupertino_suit_spade"
    SUIT_SPADE_FILL = "cupertino_suit_spade_fill"
    SUM = "cupertino_sum"
    SUN_DUST = "cupertino_sun_dust"
    SUN_DUST_FILL = "cupertino_sun_dust_fill"
    SUN_HAZE = "cupertino_sun_haze"
    SUN_HAZE_FILL = "cupertino_sun_haze_fill"
    SUN_MAX = "cupertino_sun_max"
    SUN_MAX_FILL = "cupertino_sun_max_fill"
    SUN_MIN = "cupertino_sun_min"
    SUN_MIN_FILL = "cupertino_sun_min_fill"
    SUNRISE = "cupertino_sunrise"
    SUNRISE_FILL = "cupertino_sunrise_fill"
    SUNSET = "cupertino_sunset"
    SUNSET_FILL = "cupertino_sunset_fill"
    T_BUBBLE = "cupertino_t_bubble"
    T_BUBBLE_FILL = "cupertino_t_bubble_fill"
    TABLE = "cupertino_table"
    TABLE_BADGE_MORE = "cupertino_table_badge_more"
    TABLE_BADGE_MORE_FILL = "cupertino_table_badge_more_fill"
    TABLE_FILL = "cupertino_table_fill"
    TAG_CIRCLE = "cupertino_tag_circle"
    TAG_CIRCLE_FILL = "cupertino_tag_circle_fill"
    TAG_FILL = "cupertino_tag_fill"
    TEXT_ALIGNCENTER = "cupertino_text_aligncenter"
    TEXT_ALIGNLEFT = "cupertino_text_alignleft"
    TEXT_ALIGNRIGHT = "cupertino_text_alignright"
    TEXT_APPEND = "cupertino_text_append"
    TEXT_BADGE_CHECKMARK = "cupertino_text_badge_checkmark"
    TEXT_BADGE_MINUS = "cupertino_text_badge_minus"
    TEXT_BADGE_PLUS = "cupertino_text_badge_plus"
    TEXT_BADGE_STAR = "cupertino_text_badge_star"
    TEXT_BADGE_XMARK = "cupertino_text_badge_xmark"
    TEXT_BUBBLE = "cupertino_text_bubble"
    TEXT_BUBBLE_FILL = "cupertino_text_bubble_fill"
    TEXT_CURSOR = "cupertino_text_cursor"
    TEXT_INSERT = "cupertino_text_insert"
    TEXT_JUSTIFY = "cupertino_text_justify"
    TEXT_JUSTIFYLEFT = "cupertino_text_justifyleft"
    TEXT_JUSTIFYRIGHT = "cupertino_text_justifyright"
    TEXT_QUOTE = "cupertino_text_quote"
    TEXTBOX = "cupertino_textbox"
    TEXTFORMAT = "cupertino_textformat"
    TEXTFORMAT_123 = "cupertino_textformat_123"
    TEXTFORMAT_ABC = "cupertino_textformat_abc"
    TEXTFORMAT_ABC_DOTTEDUNDERLINE = "cupertino_textformat_abc_dottedunderline"
    TEXTFORMAT_ALT = "cupertino_textformat_alt"
    TEXTFORMAT_SIZE = "cupertino_textformat_size"
    TEXTFORMAT_SUBSCRIPT = "cupertino_textformat_subscript"
    TEXTFORMAT_SUPERSCRIPT = "cupertino_textformat_superscript"
    THERMOMETER = "cupertino_thermometer"
    THERMOMETER_SNOWFLAKE = "cupertino_thermometer_snowflake"
    THERMOMETER_SUN = "cupertino_thermometer_sun"
    TICKET = "cupertino_ticket"
    TICKET_FILL = "cupertino_ticket_fill"
    TICKETS = "cupertino_tickets"
    TICKETS_FILL = "cupertino_tickets_fill"
    TIMELAPSE = "cupertino_timelapse"
    TIMER = "cupertino_timer"
    TIMER_FILL = "cupertino_timer_fill"
    TODAY = "cupertino_today"
    TODAY_FILL = "cupertino_today_fill"
    TORNADO = "cupertino_tornado"
    TORTOISE = "cupertino_tortoise"
    TORTOISE_FILL = "cupertino_tortoise_fill"
    TRAM_FILL = "cupertino_tram_fill"
    TRASH = "cupertino_trash"
    TRASH_CIRCLE = "cupertino_trash_circle"
    TRASH_CIRCLE_FILL = "cupertino_trash_circle_fill"
    TRASH_FILL = "cupertino_trash_fill"
    TRASH_SLASH = "cupertino_trash_slash"
    TRASH_SLASH_FILL = "cupertino_trash_slash_fill"
    TRAY = "cupertino_tray"
    TRAY_2 = "cupertino_tray_2"
    TRAY_2_FILL = "cupertino_tray_2_fill"
    TRAY_ARROW_DOWN = "cupertino_tray_arrow_down"
    TRAY_ARROW_DOWN_FILL = "cupertino_tray_arrow_down_fill"
    TRAY_ARROW_UP = "cupertino_tray_arrow_up"
    TRAY_ARROW_UP_FILL = "cupertino_tray_arrow_up_fill"
    TRAY_FILL = "cupertino_tray_fill"
    TRAY_FULL = "cupertino_tray_full"
    TRAY_FULL_FILL = "cupertino_tray_full_fill"
    TREE = "cupertino_tree"
    TRIANGLE = "cupertino_triangle"
    TRIANGLE_FILL = "cupertino_triangle_fill"
    TRIANGLE_LEFTHALF_FILL = "cupertino_triangle_lefthalf_fill"
    TRIANGLE_RIGHTHALF_FILL = "cupertino_triangle_righthalf_fill"
    TROPICALSTORM = "cupertino_tropicalstorm"
    TUNINGFORK = "cupertino_tuningfork"
    TV = "cupertino_tv"
    TV_CIRCLE = "cupertino_tv_circle"
    TV_CIRCLE_FILL = "cupertino_tv_circle_fill"
    TV_FILL = "cupertino_tv_fill"
    TV_MUSIC_NOTE = "cupertino_tv_music_note"
    TV_MUSIC_NOTE_FILL = "cupertino_tv_music_note_fill"
    UIWINDOW_SPLIT_2X1 = "cupertino_uiwindow_split_2x1"
    UMBRELLA = "cupertino_umbrella"
    UMBRELLA_FILL = "cupertino_umbrella_fill"
    UNDERLINE = "cupertino_underline"
    UPLOAD_CIRCLE = "cupertino_upload_circle"
    UPLOAD_CIRCLE_FILL = "cupertino_upload_circle_fill"
    VIDEOCAM = "cupertino_videocam"
    VIDEOCAM_CIRCLE = "cupertino_videocam_circle"
    VIDEOCAM_CIRCLE_FILL = "cupertino_videocam_circle_fill"
    VIDEOCAM_FILL = "cupertino_videocam_fill"
    VIEW_2D = "cupertino_view_2d"
    VIEW_3D = "cupertino_view_3d"
    VIEWFINDER = "cupertino_viewfinder"
    VIEWFINDER_CIRCLE = "cupertino_viewfinder_circle"
    VIEWFINDER_CIRCLE_FILL = "cupertino_viewfinder_circle_fill"
    WAND_RAYS = "cupertino_wand_rays"
    WAND_RAYS_INVERSE = "cupertino_wand_rays_inverse"
    WAND_STARS = "cupertino_wand_stars"
    WAND_STARS_INVERSE = "cupertino_wand_stars_inverse"
    WAVEFORM = "cupertino_waveform"
    WAVEFORM_CIRCLE = "cupertino_waveform_circle"
    WAVEFORM_CIRCLE_FILL = "cupertino_waveform_circle_fill"
    WAVEFORM_PATH = "cupertino_waveform_path"
    WAVEFORM_PATH_BADGE_MINUS = "cupertino_waveform_path_badge_minus"
    WAVEFORM_PATH_BADGE_PLUS = "cupertino_waveform_path_badge_plus"
    WAVEFORM_PATH_ECG = "cupertino_waveform_path_ecg"
    WIFI = "cupertino_wifi"
    WIFI_EXCLAMATIONMARK = "cupertino_wifi_exclamationmark"
    WIFI_SLASH = "cupertino_wifi_slash"
    WIND = "cupertino_wind"
    WIND_SNOW = "cupertino_wind_snow"
    WRENCH = "cupertino_wrench"
    WRENCH_FILL = "cupertino_wrench_fill"
    XMARK = "cupertino_xmark"
    XMARK_CIRCLE = "cupertino_xmark_circle"
    XMARK_CIRCLE_FILL = "cupertino_xmark_circle_fill"
    XMARK_OCTAGON = "cupertino_xmark_octagon"
    XMARK_OCTAGON_FILL = "cupertino_xmark_octagon_fill"
    XMARK_RECTANGLE = "cupertino_xmark_rectangle"
    XMARK_RECTANGLE_FILL = "cupertino_xmark_rectangle_fill"
    XMARK_SEAL = "cupertino_xmark_seal"
    XMARK_SEAL_FILL = "cupertino_xmark_seal_fill"
    XMARK_SHIELD = "cupertino_xmark_shield"
    XMARK_SHIELD_FILL = "cupertino_xmark_shield_fill"
    XMARK_SQUARE = "cupertino_xmark_square"
    XMARK_SQUARE_FILL = "cupertino_xmark_square_fill"
    ZOOM_IN = "cupertino_zoom_in"
    ZOOM_OUT = "cupertino_zoom_out"
    ZZZ = "cupertino_zzz"



#!/usr/bin/env python3
"""
Bağımlılık Yönetimi Komutu
==========================

Bu modül bağımlılık yönetimi için CLI komutlarını sağlar.
"""

import os
import sys
import argparse
from pathlib import Path
from typing import Dict, List, Any, Optional

from dependency_resolver import (
    check_and_install_python_dependencies,
    check_and_install_lua_dependencies,
    check_engine_availability,
    get_dependency_report,
    get_system_dependency_report,
    get_enhanced_system_dependency_report,
    resolve_all_dependencies
)
from package_registry import get_apps_directory, list_packages, get_manifest

def handle_dependency_check(args):
    """Bağımlılık kontrolü komutunu işler"""
    app_name = args.app_name
    
    if app_name:
        # Belirli bir uygulama için bağımlılık kontrolü
        print(f"🔍 {app_name} bağımlılık kontrolü...")
        print("=" * 50)
        
        # Bağımlılık raporu
        report = get_dependency_report(app_name)
        print(report)
        
        # Detaylı çözümleme
        resolution = resolve_all_dependencies(app_name)
        if resolution["status"] == "resolved":
            print("✅ Tüm bağımlılıklar çözümlenmiş!")
        elif resolution["status"] == "missing_dependencies":
            print("❌ Eksik bağımlılıklar var!")
        else:
            print(f"⚠️  Durum: {resolution['status']}")
        
    else:
        # Sistem geneli bağımlılık kontrolü
        print("🔍 Sistem geneli bağımlılık kontrolü...")
        print("=" * 50)
        
        report = get_system_dependency_report()
        print(report)
        
        # Gelişmiş sistem raporu
        enhanced_report = get_enhanced_system_dependency_report()
        print("\n" + enhanced_report)

def handle_dependency_install(args):
    """Bağımlılık kurulumu komutunu işler"""
    app_name = args.app_name
    force = args.force
    
    if not app_name:
        print("❌ Uygulama adı belirtilmelidir!")
        return False, "Uygulama adı eksik"
    
    apps_dir = get_apps_directory()
    app_path = os.path.join(apps_dir, app_name)
    
    if not os.path.exists(app_path):
        return False, f"Uygulama bulunamadı: {app_name}"
    
    print(f"🔧 {app_name} bağımlılıkları kuruluyor...")
    print("=" * 50)
    
    # Manifest'i oku
    manifest_path = os.path.join(app_path, "manifest.json")
    if not os.path.exists(manifest_path):
        return False, "Manifest dosyası bulunamadı"
    
    try:
        import json
        with open(manifest_path, 'r', encoding='utf-8') as f:
            manifest = json.load(f)
    except Exception as e:
        return False, f"Manifest okuma hatası: {e}"
    
    language = manifest.get('language', 'unknown')
    
    if language == 'python':
        success, message, missing_packages = check_and_install_python_dependencies(app_path)
        if success:
            if missing_packages:
                print(f"✅ {message}")
                print(f"📦 Kurulan paketler: {', '.join(missing_packages)}")
            else:
                print("✅ Tüm Python bağımlılıkları zaten kurulu")
            return True, message
        else:
            return False, message
    
    elif language == 'lua':
        success, message, missing_packages = check_and_install_lua_dependencies(app_path)
        if success:
            if missing_packages:
                print(f"✅ {message}")
                print(f"🪨 Kurulan paketler: {', '.join(missing_packages)}")
            else:
                print("✅ Tüm Lua bağımlılıkları zaten kurulu")
            return True, message
        else:
            return False, message
    
    else:
        return False, f"Desteklenmeyen dil: {language}"

def handle_engine_check(args):
    """Engine kontrolü komutunu işler"""
    app_name = args.app_name
    
    if app_name:
        # Belirli bir uygulama için engine kontrolü
        apps_dir = get_apps_directory()
        app_path = os.path.join(apps_dir, app_name)
        
        if not os.path.exists(app_path):
            return False, f"Uygulama bulunamadı: {app_name}"
        
        print(f"🔧 {app_name} engine kontrolü...")
        print("=" * 50)
        
        available, message, engine_info = check_engine_availability(app_path)
        
        if available:
            print(f"✅ {message}")
        else:
            print(f"❌ {message}")
        
        if engine_info:
            print(f"📊 Engine Bilgileri:")
            print(f"  - Ad: {engine_info.get('name', 'Bilinmiyor')}")
            print(f"  - Dil: {engine_info.get('language', 'Bilinmiyor')}")
            print(f"  - Gerekli: {engine_info.get('required', False)}")
            print(f"  - Mevcut: {engine_info.get('available', False)}")
        
        return available, message
    
    else:
        # Tüm uygulamalar için engine kontrolü
        print("🔧 Sistem geneli engine kontrolü...")
        print("=" * 50)
        
        packages = list_packages()
        engine_report = {
            "total_apps": len(packages),
            "apps_with_engines": 0,
            "apps_with_missing_engines": 0,
            "engine_details": []
        }
        
        for package in packages:
            app_name = package['name']
            apps_dir = get_apps_directory()
            app_path = os.path.join(apps_dir, app_name)
            
            available, message, engine_info = check_engine_availability(app_path)
            
            if engine_info:
                engine_report["apps_with_engines"] += 1
                if not available:
                    engine_report["apps_with_missing_engines"] += 1
                
                engine_report["engine_details"].append({
                    "app": app_name,
                    "engine": engine_info.get('name', 'Bilinmiyor'),
                    "language": engine_info.get('language', 'Bilinmiyor'),
                    "available": available,
                    "message": message
                })
        
        # Raporu yazdır
        print(f"📊 Engine Raporu:")
        print(f"  - Toplam Uygulama: {engine_report['total_apps']}")
        print(f"  - Engine Gereksinimi: {engine_report['apps_with_engines']}")
        print(f"  - Eksik Engine: {engine_report['apps_with_missing_engines']}")
        print()
        
        if engine_report["engine_details"]:
            print("🔍 Detaylı Engine Durumu:")
            for detail in engine_report["engine_details"]:
                status = "✅" if detail["available"] else "❌"
                print(f"  {status} {detail['app']}: {detail['engine']} ({detail['language']})")
        
        return True, "Engine kontrolü tamamlandı"

def handle_dependency_tree(args):
    """Bağımlılık ağacı komutunu işler"""
    app_name = args.app_name
    
    if not app_name:
        print("❌ Uygulama adı belirtilmelidir!")
        return False, "Uygulama adı eksik"
    
    print(f"🌳 {app_name} bağımlılık ağacı...")
    print("=" * 50)
    
    resolution = resolve_all_dependencies(app_name)
    
    if resolution["status"] == "error":
        print(f"❌ Hata: {resolution.get('dependency_tree', {}).get('error', 'Bilinmeyen hata')}")
        return False, "Bağımlılık ağacı oluşturulamadı"
    
    tree = resolution["dependency_tree"]
    
    def print_tree(node, level=0):
        indent = "  " * level
        status = "✅" if node.get("missing_dependencies") == [] else "❌"
        print(f"{indent}{status} {node['name']} (v{node['version']}) [{node['language']}]")
        
        if node.get("missing_dependencies"):
            for missing in node["missing_dependencies"]:
                print(f"{indent}  ❌ Eksik: {missing}")
        
        for dep in node.get("dependencies", []):
            print_tree(dep, level + 1)
    
    print_tree(tree)
    
    print(f"\n📊 Özet:")
    print(f"  - Durum: {resolution['status']}")
    print(f"  - Toplam Bağımlılık: {len(resolution['all_dependencies'])}")
    print(f"  - Eksik: {len(resolution['missing_dependencies'])}")
    
    return True, "Bağımlılık ağacı gösterildi"

def main():
    """Ana CLI fonksiyonu"""
    parser = argparse.ArgumentParser(
        description="CLAPP Bağımlılık Yönetimi",
        formatter_class=argparse.RawDescriptionHelpFormatter,
        epilog="""
Örnekler:
  clapp dependency check hello-python     # Belirli uygulama bağımlılık kontrolü
  clapp dependency check                  # Sistem geneli bağımlılık kontrolü
  clapp dependency install hello-python   # Bağımlılıkları kur
  clapp dependency engine hello-python    # Engine kontrolü
  clapp dependency tree hello-python      # Bağımlılık ağacı
        """
    )
    
    subparsers = parser.add_subparsers(dest='command', help='Alt komutlar')
    
    # Check komutu
    check_parser = subparsers.add_parser('check', help='Bağımlılık kontrolü')
    check_parser.add_argument('app_name', nargs='?', help='Uygulama adı (opsiyonel)')
    
    # Install komutu
    install_parser = subparsers.add_parser('install', help='Bağımlılık kurulumu')
    install_parser.add_argument('app_name', help='Uygulama adı')
    install_parser.add_argument('--force', '-f', action='store_true', help='Zorla kurulum')
    
    # Engine komutu
    engine_parser = subparsers.add_parser('engine', help='Engine kontrolü')
    engine_parser.add_argument('app_name', nargs='?', help='Uygulama adı (opsiyonel)')
    
    # Tree komutu
    tree_parser = subparsers.add_parser('tree', help='Bağımlılık ağacı')
    tree_parser.add_argument('app_name', help='Uygulama adı')
    
    args = parser.parse_args()
    
    if not args.command:
        parser.print_help()
        return
    
    try:
        if args.command == 'check':
            handle_dependency_check(args)
        elif args.command == 'install':
            success, message = handle_dependency_install(args)
            if not success:
                print(f"❌ {message}")
                sys.exit(1)
        elif args.command == 'engine':
            success, message = handle_engine_check(args)
            if not success:
                print(f"❌ {message}")
                sys.exit(1)
        elif args.command == 'tree':
            success, message = handle_dependency_tree(args)
            if not success:
                print(f"❌ {message}")
                sys.exit(1)
    
    except KeyboardInterrupt:
        print("\n⚠️  İşlem iptal edildi")
        sys.exit(1)
    except Exception as e:
        print(f"❌ Beklenmeyen hata: {e}")
        sys.exit(1)

if __name__ == "__main__":
    main() 


from typing import Any, Optional

from flet.core.control import Control, OptionalNumber
from flet.core.ref import Ref


class ChartAxisLabel(Control):
    def __init__(
        self,
        value: OptionalNumber = None,
        label: Optional[Control] = None,
        #
        # Specific
        #
        ref: Optional[Ref] = None,
        disabled: Optional[bool] = None,
        visible: Optional[bool] = None,
        data: Any = None,
    ):

        Control.__init__(
            self,
            ref=ref,
            disabled=disabled,
            visible=visible,
            data=data,
        )

        self.value = value
        self.label = label

    def _get_control_name(self):
        return "l"

    def _get_children(self):
        children = []
        if self.__label:
            children.append(self.__label)
        return children

    # value
    @property
    def value(self) -> float:
        return self._get_attr("value", data_type="float", def_value=1.0)

    @value.setter
    def value(self, value: OptionalNumber):
        self._set_attr("value", value)

    # label
    @property
    def label(self) -> Optional[Control]:
        return self.__label

    @label.setter
    def label(self, value: Optional[Control]):
        self.__label = value



import subprocess
import sys

from flet.utils.pip import ensure_flet_cli_package_installed


def main():
    ensure_flet_cli_package_installed()
    import flet_cli.cli

    flet_cli.cli.main()


if __name__ == "__main__":
    main()



from typing import Any, List, Optional, Sequence, Union

from flet.core.adaptive_control import AdaptiveControl
from flet.core.animation import AnimationValue
from flet.core.constrained_control import ConstrainedControl
from flet.core.control import Control, OptionalNumber
from flet.core.ref import Ref
from flet.core.scrollable_control import OnScrollEvent, ScrollableControl
from flet.core.types import (
    ClipBehavior,
    OffsetValue,
    OptionalControlEventCallable,
    OptionalEventCallable,
    PaddingValue,
    ResponsiveNumber,
    RotateValue,
    ScaleValue,
)


class ListView(ConstrainedControl, ScrollableControl, AdaptiveControl):
    """
    A scrollable list of controls arranged linearly.

    ListView is the most commonly used scrolling control. It displays its children one after another in the scroll direction. In the cross axis, the children are required to fill the ListView.

    Example:

    ```
    from time import sleep
    import flet as ft

    def main(page: ft.Page):
        page.title = "Auto-scrolling ListView"

        lv = ft.ListView(expand=1, spacing=10, padding=20, auto_scroll=True)

        count = 1

        for i in range(0, 60):
            lv.controls.append(ft.Text(f"Line {count}"))
            count += 1

        page.add(lv)

        for i in range(0, 60):
            sleep(1)
            lv.controls.append(ft.Text(f"Line {count}"))
            count += 1
            page.update()

    ft.app(target=main)
    ```

    -----

    Online docs: https://flet.dev/docs/controls/listview
    """

    def __init__(
        self,
        controls: Optional[Sequence[Control]] = None,
        horizontal: Optional[bool] = None,
        spacing: OptionalNumber = None,
        item_extent: OptionalNumber = None,
        first_item_prototype: Optional[bool] = None,
        divider_thickness: OptionalNumber = None,
        padding: Optional[PaddingValue] = None,
        clip_behavior: Optional[ClipBehavior] = None,
        semantic_child_count: Optional[int] = None,
        cache_extent: OptionalNumber = None,
        build_controls_on_demand: Optional[bool] = None,
        #
        # ScrollableControl specific
        #
        auto_scroll: Optional[bool] = None,
        reverse: Optional[bool] = None,
        on_scroll_interval: OptionalNumber = None,
        on_scroll: OptionalEventCallable[OnScrollEvent] = None,
        #
        # ConstrainedControl
        #
        ref: Optional[Ref] = None,
        key: Optional[str] = None,
        width: OptionalNumber = None,
        height: OptionalNumber = None,
        left: OptionalNumber = None,
        top: OptionalNumber = None,
        right: OptionalNumber = None,
        bottom: OptionalNumber = None,
        expand: Union[None, bool, int] = None,
        expand_loose: Optional[bool] = None,
        col: Optional[ResponsiveNumber] = None,
        opacity: OptionalNumber = None,
        rotate: Optional[RotateValue] = None,
        scale: Optional[ScaleValue] = None,
        offset: Optional[OffsetValue] = None,
        aspect_ratio: OptionalNumber = None,
        animate_opacity: Optional[AnimationValue] = None,
        animate_size: Optional[AnimationValue] = None,
        animate_position: Optional[AnimationValue] = None,
        animate_rotation: Optional[AnimationValue] = None,
        animate_scale: Optional[AnimationValue] = None,
        animate_offset: Optional[AnimationValue] = None,
        on_animation_end: OptionalControlEventCallable = None,
        visible: Optional[bool] = None,
        disabled: Optional[bool] = None,
        data: Any = None,
        #
        # AdaptiveControl
        #
        adaptive: Optional[bool] = None,
    ):
        ConstrainedControl.__init__(
            self,
            ref=ref,
            key=key,
            width=width,
            height=height,
            left=left,
            top=top,
            right=right,
            bottom=bottom,
            expand=expand,
            expand_loose=expand_loose,
            col=col,
            opacity=opacity,
            rotate=rotate,
            scale=scale,
            offset=offset,
            aspect_ratio=aspect_ratio,
            animate_opacity=animate_opacity,
            animate_size=animate_size,
            animate_position=animate_position,
            animate_rotation=animate_rotation,
            animate_scale=animate_scale,
            animate_offset=animate_offset,
            on_animation_end=on_animation_end,
            visible=visible,
            disabled=disabled,
            data=data,
        )

        ScrollableControl.__init__(
            self,
            auto_scroll=auto_scroll,
            reverse=reverse,
            on_scroll_interval=on_scroll_interval,
            on_scroll=on_scroll,
        )

        AdaptiveControl.__init__(self, adaptive=adaptive)

        self.__controls: List[Control] = []
        self.controls = controls
        self.horizontal = horizontal
        self.spacing = spacing
        self.divider_thickness = divider_thickness
        self.item_extent = item_extent
        self.first_item_prototype = first_item_prototype
        self.padding = padding
        self.clip_behavior = clip_behavior
        self.semantic_child_count = semantic_child_count
        self.cache_extent = cache_extent
        self.build_controls_on_demand = build_controls_on_demand

    def _get_control_name(self):
        return "listview"

    def before_update(self):
        super().before_update()
        self._set_attr_json("padding", self.__padding)

    def _get_children(self):
        return self.__controls

    def clean(self):
        super().clean()
        self.__controls.clear()

    # horizontal
    @property
    def horizontal(self) -> bool:
        return self._get_attr("horizontal", data_type="bool", def_value=False)

    @horizontal.setter
    def horizontal(self, value: Optional[bool]):
        self._set_attr("horizontal", value)

    # spacing
    @property
    def spacing(self) -> OptionalNumber:
        return self._get_attr("spacing", data_type="float")

    @spacing.setter
    def spacing(self, value: OptionalNumber):
        self._set_attr("spacing", value)

    # divider_thickness
    @property
    def divider_thickness(self) -> OptionalNumber:
        return self._get_attr("dividerThickness")

    @divider_thickness.setter
    def divider_thickness(self, value: OptionalNumber):
        self._set_attr("dividerThickness", value)

    # item_extent
    @property
    def item_extent(self) -> OptionalNumber:
        return self._get_attr("itemExtent")

    @item_extent.setter
    def item_extent(self, value: OptionalNumber):
        self._set_attr("itemExtent", value)

    # cache_extent
    @property
    def cache_extent(self) -> OptionalNumber:
        return self._get_attr("cacheExtent", data_type="float")

    @cache_extent.setter
    def cache_extent(self, value: OptionalNumber):
        self._set_attr("cacheExtent", value)

    # first_item_prototype
    @property
    def first_item_prototype(self) -> bool:
        return self._get_attr("firstItemPrototype", data_type="bool", def_value=False)

    @first_item_prototype.setter
    def first_item_prototype(self, value: Optional[bool]):
        self._set_attr("firstItemPrototype", value)

    # padding
    @property
    def padding(self) -> Optional[PaddingValue]:
        return self.__padding

    @padding.setter
    def padding(self, value: Optional[PaddingValue]):
        self.__padding = value

    # controls
    @property
    def controls(self) -> List[Control]:
        return self.__controls

    @controls.setter
    def controls(self, value: Optional[Sequence[Control]]):
        self.__controls = list(value) if value is not None else []

    # clip_behavior
    @property
    def clip_behavior(self) -> Optional[ClipBehavior]:
        return self.__clip_behavior

    @clip_behavior.setter
    def clip_behavior(self, value: Optional[ClipBehavior]):
        self.__clip_behavior = value
        self._set_enum_attr("clipBehavior", value, ClipBehavior)

    # semantic_child_count
    @property
    def semantic_child_count(self) -> Optional[int]:
        return self._get_attr("semanticChildCount", data_type="int")

    @semantic_child_count.setter
    def semantic_child_count(self, value: Optional[int]):
        self._set_attr("semanticChildCount", value)

    # build_controls_on_demand
    @property
    def build_controls_on_demand(self) -> Optional[bool]:
        return self._get_attr("buildControlsOnDemand", data_type="bool", def_value=True)

    @build_controls_on_demand.setter
    def build_controls_on_demand(self, value: Optional[bool]):
        self._set_attr("buildControlsOnDemand", value)



import os
import shutil
import sys


def is_within_directory(directory, target):
    abs_directory = os.path.abspath(directory)
    abs_target = os.path.abspath(target)

    prefix = os.path.commonprefix([abs_directory, abs_target])

    return prefix == abs_directory


def safe_tar_extractall(tar, path=".", members=None, *, numeric_owner=False):
    for member in tar.getmembers():
        member_path = os.path.join(path, member.name)
        if not is_within_directory(path, member_path):
            raise Exception("Attempted Path Traversal in Tar File")

    tar.extractall(path, members, numeric_owner=numeric_owner)


def copy_tree(src, dst, ignore=None):
    return shutil.copytree(src, dst, ignore=ignore, symlinks=True, dirs_exist_ok=True)


# https://stackoverflow.com/questions/377017/test-if-executable-exists-in-python
def which(program, exclude_exe=None):
    import os

    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    for path in os.environ["PATH"].split(os.pathsep):
        exe_file = os.path.join(path, program)
        if is_exe(exe_file) and (
            exclude_exe is None
            or (exclude_exe is not None and exclude_exe.lower() != exe_file.lower())
        ):
            return exe_file

    return None


def cleanup_path(path: str, executable: str):
    cleaned_dirs = []
    for path_dir in path.split(os.pathsep):
        found = False
        for file_name in [executable, f"{executable}.bat", f"{executable}.cmd"]:
            if os.path.isfile(os.path.join(path_dir, file_name)):
                found = True
                break
        if not found:
            cleaned_dirs.append(path_dir)

    return os.pathsep.join(cleaned_dirs)


def get_current_script_dir():
    pathname = os.path.dirname(sys.argv[0])
    return os.path.abspath(pathname)



from typing import Any, Optional, Union

from flet.core.adaptive_control import AdaptiveControl
from flet.core.animation import AnimationValue
from flet.core.app_bar import AppBar
from flet.core.badge import BadgeValue
from flet.core.bottom_app_bar import BottomAppBar
from flet.core.constrained_control import ConstrainedControl
from flet.core.control import Control, OptionalNumber
from flet.core.cupertino_app_bar import CupertinoAppBar
from flet.core.cupertino_navigation_bar import CupertinoNavigationBar
from flet.core.floating_action_button import FloatingActionButton
from flet.core.navigation_bar import NavigationBar
from flet.core.navigation_drawer import NavigationDrawer
from flet.core.ref import Ref
from flet.core.tooltip import TooltipValue
from flet.core.types import (
    ColorEnums,
    ColorValue,
    FloatingActionButtonLocation,
    OffsetValue,
    OptionalControlEventCallable,
    ResponsiveNumber,
    RotateValue,
    ScaleValue,
)


class Pagelet(ConstrainedControl, AdaptiveControl):
    """
        Pagelet implements the basic Material Design visual layout structure.

        Use it for projects that require "page within a page" layouts with its own AppBar, BottomBar, Drawer, such as demos and galleries.

        Example:
        ```
    import flet as ft


    def main(page: ft.Page):
        page.add(
            ft.Pagelet(
                appbar=ft.CupertinoAppBar(middle=ft.Text("AppBar title")),
                content=ft.Text("This is pagelet"),
            )
        )


    ft.app(target=main)
        ```

        -----

        Online docs: https://flet.dev/docs/controls/pagelet
    """

    def __init__(
        self,
        content: Control,
        appbar: Union[AppBar, CupertinoAppBar, None] = None,
        navigation_bar: Union[NavigationBar, CupertinoNavigationBar, None] = None,
        bottom_app_bar: Optional[BottomAppBar] = None,
        bottom_sheet: Optional[Control] = None,
        drawer: Optional[NavigationDrawer] = None,
        end_drawer: Optional[NavigationDrawer] = None,
        floating_action_button: Optional[FloatingActionButton] = None,
        floating_action_button_location: Union[
            FloatingActionButtonLocation, OffsetValue
        ] = None,
        bgcolor: Optional[ColorValue] = None,
        #
        # ConstrainedControl
        #
        ref: Optional[Ref] = None,
        width: OptionalNumber = None,
        height: OptionalNumber = None,
        left: OptionalNumber = None,
        top: OptionalNumber = None,
        right: OptionalNumber = None,
        bottom: OptionalNumber = None,
        expand: Union[None, bool, int] = None,
        expand_loose: Optional[bool] = None,
        col: Optional[ResponsiveNumber] = None,
        opacity: OptionalNumber = None,
        rotate: Optional[RotateValue] = None,
        scale: Optional[ScaleValue] = None,
        offset: Optional[OffsetValue] = None,
        aspect_ratio: OptionalNumber = None,
        animate_opacity: Optional[AnimationValue] = None,
        animate_size: Optional[AnimationValue] = None,
        animate_position: Optional[AnimationValue] = None,
        animate_rotation: Optional[AnimationValue] = None,
        animate_scale: Optional[AnimationValue] = None,
        animate_offset: Optional[AnimationValue] = None,
        on_animation_end: OptionalControlEventCallable = None,
        tooltip: Optional[TooltipValue] = None,
        badge: Optional[BadgeValue] = None,
        visible: Optional[bool] = None,
        disabled: Optional[bool] = None,
        data: Any = None,
        key: Optional[str] = None,
        #
        # AdaptiveControl
        #
        adaptive: Optional[bool] = None,
    ):
        ConstrainedControl.__init__(
            self,
            ref=ref,
            key=key,
            width=width,
            height=height,
            left=left,
            top=top,
            right=right,
            bottom=bottom,
            expand=expand,
            expand_loose=expand_loose,
            col=col,
            opacity=opacity,
            rotate=rotate,
            scale=scale,
            offset=offset,
            aspect_ratio=aspect_ratio,
            animate_opacity=animate_opacity,
            animate_size=animate_size,
            animate_position=animate_position,
            animate_rotation=animate_rotation,
            animate_scale=animate_scale,
            animate_offset=animate_offset,
            on_animation_end=on_animation_end,
            tooltip=tooltip,
            badge=badge,
            visible=visible,
            disabled=disabled,
            data=data,
        )

        AdaptiveControl.__init__(self, adaptive=adaptive)

        self.content = content
        self.appbar = appbar
        self.bgcolor = bgcolor
        self.navigation_bar = navigation_bar
        self.bottom_appbar = bottom_app_bar
        self.bottom_sheet = bottom_sheet
        self.drawer = drawer
        self.end_drawer = end_drawer
        self.floating_action_button = floating_action_button
        self.floating_action_button_location = floating_action_button_location

    def _get_control_name(self):
        return "pagelet"

    def _get_children(self):
        self.__content._set_attr_internal("n", "content")
        children = [self.__content]
        if self.__appbar:
            self.__appbar._set_attr_internal("n", "appbar")
            children.append(self.__appbar)
        if self.__navigation_bar:
            self.__navigation_bar._set_attr_internal("n", "navigationbar")
            children.append(self.__navigation_bar)
        if self.__bottom_appbar:
            self.__bottom_appbar._set_attr_internal("n", "bottomappbar")
            children.append(self.__bottom_appbar)
        if self.__bottom_sheet:
            self.__bottom_sheet._set_attr_internal("n", "bottomsheet")
            children.append(self.__bottom_sheet)
        if self.__drawer:
            self.__drawer._set_attr_internal("n", "drawer")
            children.append(self.__drawer)
        if self.__end_drawer:
            self.__end_drawer._set_attr_internal("n", "enddrawer")
            children.append(self.__end_drawer)
        if self.__floating_action_button:
            self.__floating_action_button._set_attr_internal(
                "n", "floatingactionbutton"
            )
            children.append(self.__floating_action_button)
        return children

    def before_update(self):
        super().before_update()
        assert self.__content.visible, "content must be visible"

    # Drawer
    #
    def show_drawer(self, drawer: NavigationDrawer):
        self.drawer = drawer
        self.drawer.open = True
        self.update()

    def close_drawer(self):
        if self.drawer is not None:
            self.drawer.open = False
            self.update()

    # End_drawer
    #
    def show_end_drawer(self, end_drawer: NavigationDrawer):
        self.end_drawer = end_drawer
        self.end_drawer.open = True
        self.update()

    def close_end_drawer(self):
        if self.end_drawer is not None:
            self.end_drawer.open = False
            self.update()

    # appbar
    @property
    def appbar(self) -> Union[AppBar, CupertinoAppBar, None]:
        return self.__appbar

    @appbar.setter
    def appbar(self, value: Union[AppBar, CupertinoAppBar, None]):
        self.__appbar = value

    # content
    @property
    def content(self) -> Control:
        return self.__content

    @content.setter
    def content(self, value: Control):
        self.__content = value

    # bgcolor
    @property
    def bgcolor(self) -> Optional[ColorValue]:
        return self.__bgcolor

    @bgcolor.setter
    def bgcolor(self, value: Optional[ColorValue]):
        self.__bgcolor = value
        self._set_enum_attr("bgcolor", value, ColorEnums)

    # bottom_appbar
    @property
    def bottom_appbar(self) -> Optional[BottomAppBar]:
        return self.__bottom_appbar

    @bottom_appbar.setter
    def bottom_appbar(self, value: Optional[BottomAppBar]):
        self.__bottom_appbar = value

    # navigation_bar
    @property
    def navigation_bar(self) -> Union[NavigationBar, CupertinoNavigationBar, None]:
        return self.__navigation_bar

    @navigation_bar.setter
    def navigation_bar(
        self,
        value: Union[NavigationBar, CupertinoNavigationBar, None],
    ):
        self.__navigation_bar = value

    # bottom_sheet
    @property
    def bottom_sheet(self) -> Optional[Control]:
        return self.__bottom_sheet

    @bottom_sheet.setter
    def bottom_sheet(
        self,
        value: Optional[Control],
    ):
        self.__bottom_sheet = value

    # drawer
    @property
    def drawer(self) -> Optional[NavigationDrawer]:
        return self.__drawer

    @drawer.setter
    def drawer(self, value: Optional[NavigationDrawer]):
        self.__drawer = value

    # end_drawer
    @property
    def end_drawer(self) -> Optional[NavigationDrawer]:
        return self.__end_drawer

    @end_drawer.setter
    def end_drawer(self, value: Optional[NavigationDrawer]):
        self.__end_drawer = value

    # floating_action_button
    @property
    def floating_action_button(self) -> Optional[FloatingActionButton]:
        return self.__floating_action_button

    @floating_action_button.setter
    def floating_action_button(self, value: Optional[FloatingActionButton]):
        self.__floating_action_button = value

    # floating_action_button_location
    @property
    def floating_action_button_location(
        self,
    ) -> Union[FloatingActionButtonLocation, OffsetValue]:
        return self.__floating_action_button_location

    @floating_action_button_location.setter
    def floating_action_button_location(
        self, value: Union[FloatingActionButtonLocation, OffsetValue]
    ):
        self.__floating_action_button_location = value
        self._set_attr(
            "floatingActionButtonLocation",
            value.value if isinstance(value, FloatingActionButtonLocation) else value,
        )



import json
from typing import Any, Dict, Optional, Union

from flet.core.adaptive_control import AdaptiveControl
from flet.core.animation import AnimationValue
from flet.core.badge import BadgeValue
from flet.core.constrained_control import ConstrainedControl
from flet.core.control import Control, OptionalNumber
from flet.core.control_event import ControlEvent
from flet.core.event_handler import EventHandler
from flet.core.ref import Ref
from flet.core.snack_bar import DismissDirection
from flet.core.tooltip import TooltipValue
from flet.core.types import (
    OffsetValue,
    OptionalControlEventCallable,
    OptionalEventCallable,
    ResponsiveNumber,
    RotateValue,
    ScaleValue,
)


class Dismissible(ConstrainedControl, AdaptiveControl):
    """
    A control that can be dismissed by dragging in the indicated `dismiss_direction`. When dragged or flung in the
    specified `dismiss_direction`, it's content smoothly slides out of view.

    After completing the sliding animation, if a `resize_duration` is provided, this control further animates its
    height (or width, depending on what is perpendicular to the `dismiss_direction`), gradually reducing it to zero
    over the specified `resize_duration`.

    -------

    Online Docs: https://flet.dev/docs/controls/dismissible
    """

    def __init__(
        self,
        content: Control,
        background: Optional[Control] = None,
        secondary_background: Optional[Control] = None,
        dismiss_direction: Optional[DismissDirection] = None,
        dismiss_thresholds: Optional[Dict[DismissDirection, OptionalNumber]] = None,
        movement_duration: Optional[int] = None,
        resize_duration: Optional[int] = None,
        cross_axis_end_offset: OptionalNumber = None,
        on_update: OptionalEventCallable["DismissibleUpdateEvent"] = None,
        on_dismiss: OptionalEventCallable["DismissibleDismissEvent"] = None,
        on_confirm_dismiss: OptionalEventCallable["DismissibleDismissEvent"] = None,
        on_resize: OptionalControlEventCallable = None,
        #
        # ConstrainedControl
        #
        ref: Optional[Ref] = None,
        width: OptionalNumber = None,
        height: OptionalNumber = None,
        left: OptionalNumber = None,
        top: OptionalNumber = None,
        right: OptionalNumber = None,
        bottom: OptionalNumber = None,
        expand: Union[None, bool, int] = None,
        expand_loose: Optional[bool] = None,
        col: Optional[ResponsiveNumber] = None,
        opacity: OptionalNumber = None,
        rotate: Optional[RotateValue] = None,
        scale: Optional[ScaleValue] = None,
        offset: Optional[OffsetValue] = None,
        aspect_ratio: OptionalNumber = None,
        animate_opacity: Optional[AnimationValue] = None,
        animate_size: Optional[AnimationValue] = None,
        animate_position: Optional[AnimationValue] = None,
        animate_rotation: Optional[AnimationValue] = None,
        animate_scale: Optional[AnimationValue] = None,
        animate_offset: Optional[AnimationValue] = None,
        on_animation_end: OptionalControlEventCallable = None,
        tooltip: Optional[TooltipValue] = None,
        badge: Optional[BadgeValue] = None,
        visible: Optional[bool] = None,
        disabled: Optional[bool] = None,
        data: Any = None,
        key: Optional[str] = None,
        #
        # Adaptive
        #
        adaptive: Optional[bool] = None,
    ):
        ConstrainedControl.__init__(
            self,
            ref=ref,
            key=key,
            width=width,
            height=height,
            left=left,
            top=top,
            right=right,
            bottom=bottom,
            expand=expand,
            expand_loose=expand_loose,
            col=col,
            opacity=opacity,
            rotate=rotate,
            scale=scale,
            offset=offset,
            aspect_ratio=aspect_ratio,
            animate_opacity=animate_opacity,
            animate_size=animate_size,
            animate_position=animate_position,
            animate_rotation=animate_rotation,
            animate_scale=animate_scale,
            animate_offset=animate_offset,
            on_animation_end=on_animation_end,
            tooltip=tooltip,
            badge=badge,
            visible=visible,
            disabled=disabled,
            data=data,
        )

        AdaptiveControl.__init__(self, adaptive=adaptive)

        self.__on_dismiss = EventHandler(lambda e: DismissibleDismissEvent(e))
        self.__on_update = EventHandler(lambda e: DismissibleUpdateEvent(e))
        self.__on_confirm_dismiss = EventHandler(lambda e: DismissibleDismissEvent(e))

        self._add_event_handler("dismiss", self.__on_dismiss.get_handler())
        self._add_event_handler("update", self.__on_update.get_handler())
        self._add_event_handler(
            "confirm_dismiss", self.__on_confirm_dismiss.get_handler()
        )

        self.content = content
        self.background = background
        self.secondary_background = secondary_background
        self.dismiss_direction = dismiss_direction
        self.dismiss_thresholds = dismiss_thresholds
        self.movement_duration = movement_duration
        self.resize_duration = resize_duration
        self.cross_axis_end_offset = cross_axis_end_offset
        self.on_update = on_update
        self.on_dismiss = on_dismiss
        self.on_confirm_dismiss = on_confirm_dismiss
        self.on_resize = on_resize

    def _get_control_name(self):
        return "dismissible"

    def _get_children(self):
        self.__content._set_attr_internal("n", "content")
        children = [self.__content]
        if self.__background:
            self.__background._set_attr_internal("n", "background")
            children.append(self.__background)
        if self.__secondary_background:
            self.__secondary_background._set_attr_internal("n", "secondaryBackground")
            children.append(self.__secondary_background)
        return children

    def before_update(self):
        super().before_update()
        self._set_attr_json("dismissThresholds", self.__dismiss_thresholds)

    def confirm_dismiss(self, dismiss: bool):
        self.invoke_method("confirm_dismiss", {"dismiss": str(dismiss).lower()})

    # content
    @property
    def content(self) -> Control:
        return self.__content

    @content.setter
    def content(self, value: Control):
        self.__content = value

    # background
    @property
    def background(self) -> Optional[Control]:
        return self.__background

    @background.setter
    def background(self, value: Optional[Control]):
        self.__background = value

    # secondary_background
    @property
    def secondary_background(self) -> Optional[Control]:
        return self.__secondary_background

    @secondary_background.setter
    def secondary_background(self, value: Optional[Control]):
        self.__secondary_background = value

    # movementDuration
    @property
    def movement_duration(self) -> Optional[int]:
        return self._get_attr("movementDuration", data_type="int")

    @movement_duration.setter
    def movement_duration(self, value: Optional[int]):
        self._set_attr("movementDuration", value)

    # resizeDuration
    @property
    def resize_duration(self) -> Optional[int]:
        return self._get_attr("resizeDuration", data_type="int")

    @resize_duration.setter
    def resize_duration(self, value: Optional[int]):
        self._set_attr("resizeDuration", value)

    # crossAxisEndOffset
    @property
    def cross_axis_end_offset(self) -> OptionalNumber:
        return self._get_attr("crossAxisEndOffset", data_type="float")

    @cross_axis_end_offset.setter
    def cross_axis_end_offset(self, value: OptionalNumber):
        self._set_attr("crossAxisEndOffset", value)

    # dismissDirection
    @property
    def dismiss_direction(self) -> Optional[DismissDirection]:
        return self.__dismiss_direction

    @dismiss_direction.setter
    def dismiss_direction(self, value: Optional[DismissDirection]):
        self.__dismiss_direction = value
        self._set_enum_attr("dismissDirection", value, DismissDirection)

    # dismissThresholds
    @property
    def dismiss_thresholds(self) -> Optional[Dict[DismissDirection, OptionalNumber]]:
        return self.__dismiss_thresholds

    @dismiss_thresholds.setter
    def dismiss_thresholds(
        self, value: Optional[Dict[DismissDirection, OptionalNumber]]
    ):
        self.__dismiss_thresholds = value

    # on_dismiss
    @property
    def on_dismiss(self) -> OptionalEventCallable["DismissibleDismissEvent"]:
        return self.__on_dismiss.handler

    @on_dismiss.setter
    def on_dismiss(self, handler: OptionalEventCallable["DismissibleDismissEvent"]):
        self.__on_dismiss.handler = handler
        self._set_attr("onDismiss", True if handler is not None else None)

    # on_confirm_dismiss
    @property
    def on_confirm_dismiss(self) -> OptionalEventCallable["DismissibleDismissEvent"]:
        return self.__on_confirm_dismiss.handler

    @on_confirm_dismiss.setter
    def on_confirm_dismiss(
        self, handler: OptionalEventCallable["DismissibleDismissEvent"]
    ):
        self.__on_confirm_dismiss.handler = handler
        self._set_attr("onConfirmDismiss", True if handler is not None else None)

    # on_update
    @property
    def on_update(self) -> OptionalEventCallable["DismissibleUpdateEvent"]:
        return self.__on_update.handler

    @on_update.setter
    def on_update(self, handler: OptionalEventCallable["DismissibleUpdateEvent"]):
        self.__on_update.handler = handler
        self._set_attr("onUpdate", True if handler is not None else None)

    # on_resize
    @property
    def on_resize(self):
        return self._get_event_handler("resize")

    @on_resize.setter
    def on_resize(self, handler: OptionalControlEventCallable):
        self._add_event_handler("resize", handler)
        self._set_attr("onResize", True if handler is not None else None)


class DismissibleDismissEvent(ControlEvent):
    def __init__(self, e: ControlEvent):
        super().__init__(e.target, e.name, e.data, e.control, e.page)
        self.direction = DismissDirection(e.data)


class DismissibleUpdateEvent(ControlEvent):
    def __init__(self, e: ControlEvent):
        super().__init__(e.target, e.name, e.data, e.control, e.page)
        d = json.loads(e.data)
        self.direction: DismissDirection = DismissDirection(d.get("direction"))
        self.progress: float = d.get("progress")
        self.reached: bool = d.get("reached")
        self.previous_reached: bool = d.get("previous_reached")
